@@ -122,9 +122,6 @@
 /* NOTE: hard coded to 1 */
 #define USEDECOR 1
 
-/* Enables multi-pixmap themeable titlebars */
-#undef FANCY_TITLEBARS
-
 /* Enables session management functionality. */
 #undef SESSION
 
@@ -134,6 +131,9 @@
 /* Enable X output method */
 #undef HAVE_XOUTPUT_METHOD
 
+/* Enable the use of mkstemp */
+#undef HAVE_SAFTY_MKSTEMP
+
 /* Specify a type for sig_atomic_t if it's not available. */
 #undef sig_atomic_t
 
@@ -221,6 +221,12 @@ This text should not appear anywhere (but it does with autoconf-2.50+).
 @BOTTOM@
 
 
+#if RETSIGTYPE != void
+#define SIGNAL_RETURN return 0
+#else
+#define SIGNAL_RETURN return
+#endif
+
 /* Allow GCC extensions to work, if you have GCC. */
 #ifndef __attribute__
 /* This feature is available in gcc versions 2.5 and later. */
@@ -235,7 +241,6 @@ This text should not appear anywhere (but it does with autoconf-2.50+).
 #  endif
 #endif
 
-
 #if HAVE_ALLOCA_H
 #  include <alloca.h>
 #else
@@ -248,7 +253,6 @@ This text should not appear anywhere (but it does with autoconf-2.50+).
 #  endif
 #endif
 
-
 #ifdef STDC_HEADERS
 #  include <stdlib.h>
 #  include <string.h>
