@@ -81,7 +81,7 @@ extern int cmsDelayDefault;
 /* ---------------------------- included code files ------------------------ */
 
 /* ---------------------------- local types -------------------------------- */
-
+typedef enum {FakeMouseEvent, FakeKeyEvent} FakeEventType;
 /* ---------------------------- forward declarations ----------------------- */
 
 /* ---------------------------- local variables ---------------------------- */
@@ -502,6 +502,7 @@ static void do_title_style(F_CMD_ARGS, Bool do_add)
 			}
 			if (decor->min_title_height != height)
 			{
+				decor->title_height = 0;
 				decor->min_title_height = height;
 				decor->flags.has_title_height_changed = 1;
 			}
@@ -3506,14 +3507,14 @@ void CMD_BugOpts(F_CMD_ARGS)
 			switch (toggle)
 			{
 			case -1:
-				Scr.bo.DisableConfigureNotify ^= 1;
+				Scr.bo.do_disable_configure_notify ^= 1;
 				break;
 			case 0:
 			case 1:
-				Scr.bo.DisableConfigureNotify = toggle;
+				Scr.bo.do_disable_configure_notify = toggle;
 				break;
 			default:
-				Scr.bo.DisableConfigureNotify = 0;
+				Scr.bo.do_disable_configure_notify = 0;
 				break;
 			}
 		}
@@ -3522,14 +3523,14 @@ void CMD_BugOpts(F_CMD_ARGS)
 			switch (toggle)
 			{
 			case -1:
-				Scr.bo.InstallRootCmap ^= 1;
+				Scr.bo.do_install_root_cmap ^= 1;
 				break;
 			case 0:
 			case 1:
-				Scr.bo.InstallRootCmap = toggle;
+				Scr.bo.do_install_root_cmap = toggle;
 				break;
 			default:
-				Scr.bo.InstallRootCmap = 0;
+				Scr.bo.do_install_root_cmap = 0;
 				break;
 			}
 		}
@@ -3538,17 +3539,17 @@ void CMD_BugOpts(F_CMD_ARGS)
 			switch (toggle)
 			{
 			case -1:
-				Scr.bo.ModalityIsEvil ^= 1;
+				Scr.bo.is_modality_evil ^= 1;
 				break;
 			case 0:
 			case 1:
-				Scr.bo.ModalityIsEvil = toggle;
+				Scr.bo.is_modality_evil = toggle;
 				break;
 			default:
-				Scr.bo.ModalityIsEvil = 0;
+				Scr.bo.is_modality_evil = 0;
 				break;
 			}
-			if (Scr.bo.ModalityIsEvil)
+			if (Scr.bo.is_modality_evil)
 			{
 				SetMWM_INFO(Scr.NoFocusWin);
 			}
@@ -3558,14 +3559,14 @@ void CMD_BugOpts(F_CMD_ARGS)
 			switch (toggle)
 			{
 			case -1:
-				Scr.bo.RaiseHackNeeded ^= 1;
+				Scr.bo.is_raise_hack_needed ^= 1;
 				break;
 			case 0:
 			case 1:
-				Scr.bo.RaiseHackNeeded = toggle;
+				Scr.bo.is_raise_hack_needed = toggle;
 				break;
 			default:
-				Scr.bo.RaiseHackNeeded = 0;
+				Scr.bo.is_raise_hack_needed = 0;
 				break;
 			}
 		}
@@ -3574,14 +3575,14 @@ void CMD_BugOpts(F_CMD_ARGS)
 			switch (toggle)
 			{
 			case -1:
-				Scr.bo.RaiseOverUnmanaged ^= 1;
+				Scr.bo.do_raise_over_unmanaged ^= 1;
 				break;
 			case 0:
 			case 1:
-				Scr.bo.RaiseOverUnmanaged = toggle;
+				Scr.bo.do_raise_over_unmanaged = toggle;
 				break;
 			default:
-				Scr.bo.RaiseOverUnmanaged = 0;
+				Scr.bo.do_raise_over_unmanaged = 0;
 				break;
 			}
 		}
@@ -3590,14 +3591,14 @@ void CMD_BugOpts(F_CMD_ARGS)
 			switch (toggle)
 			{
 			case -1:
-				Scr.bo.FlickeringQtDialogsWorkaround ^= 1;
+				Scr.bo.do_enable_flickering_qt_dialogs_workaround ^= 1;
 				break;
 			case 0:
 			case 1:
-				Scr.bo.FlickeringQtDialogsWorkaround = toggle;
+				Scr.bo.do_enable_flickering_qt_dialogs_workaround = toggle;
 				break;
 			default:
-				Scr.bo.FlickeringQtDialogsWorkaround = 0;
+				Scr.bo.do_enable_flickering_qt_dialogs_workaround = 0;
 				break;
 			}
 		}
@@ -3605,6 +3606,38 @@ void CMD_BugOpts(F_CMD_ARGS)
 		{
 			/* work is done in EWMH_BugOpts */
 		}
+		else if (StrEquals(opt, "DisplayNewWindowNames"))
+		{
+			switch (toggle)
+			{
+			case -1:
+				Scr.bo.do_display_new_window_names ^= 1;
+				break;
+			case 0:
+			case 1:
+				Scr.bo.do_display_new_window_names = toggle;
+				break;
+			default:
+				Scr.bo.do_display_new_window_names = 0;
+				break;
+			}
+		}
+		else if (StrEquals(opt, "ExplainWindowPlacement"))
+		{
+			switch (toggle)
+			{
+			case -1:
+				Scr.bo.do_explain_window_placement ^= 1;
+				break;
+			case 0:
+			case 1:
+				Scr.bo.do_explain_window_placement = toggle;
+				break;
+			default:
+				Scr.bo.do_explain_window_placement = 0;
+				break;
+			}
+		}
 		else
 		{
 			fvwm_msg(ERR, "SetBugOptions",
@@ -3623,18 +3656,18 @@ void CMD_Emulate(F_CMD_ARGS)
 	style = PeekToken(action, NULL);
 	if (!style || StrEquals(style, "fvwm"))
 	{
-		Scr.gs.EmulateMWM = False;
-		Scr.gs.EmulateWIN = False;
+		Scr.gs.do_emulate_mwm = False;
+		Scr.gs.do_emulate_win = False;
 	}
 	else if (StrEquals(style, "mwm"))
 	{
-		Scr.gs.EmulateMWM = True;
-		Scr.gs.EmulateWIN = False;
+		Scr.gs.do_emulate_mwm = True;
+		Scr.gs.do_emulate_win = False;
 	}
 	else if (StrEquals(style, "win"))
 	{
-		Scr.gs.EmulateMWM = False;
-		Scr.gs.EmulateWIN = True;
+		Scr.gs.do_emulate_mwm = False;
+		Scr.gs.do_emulate_win = True;
 	}
 	else
 	{
@@ -3701,7 +3734,39 @@ void CMD_SetAnimation(F_CMD_ARGS)
 	return;
 }
 
-void CMD_FakeClick(F_CMD_ARGS)
+/* Determine which modifiers are required with a keycode to make <keysym>. */
+static Bool FKeysymToKeycode (Display *dpy, KeySym keysym,
+	unsigned int *keycode, unsigned int *modifiers)
+{
+	int m;
+
+	*keycode = XKeysymToKeycode(dpy, keysym);
+	*modifiers = 0;
+
+	for (m = 0; m <= 8; ++m)
+	{
+		KeySym ks = XKeycodeToKeysym(dpy, *keycode, m);
+		if (ks == keysym)
+		{
+			switch (m)
+			{
+				case 0: /* No modifiers */
+					break;
+				case 1: /* Shift modifier */
+					*modifiers |= ShiftMask;
+					break;
+				default:
+					fvwm_msg(ERR, "FKeysymToKeycode",
+						"Unhandled modifier %d", m);
+					break;
+			}
+			return True;
+		}
+	}
+	return False;
+}
+
+static void __fake_event(F_CMD_ARGS, FakeEventType type)
 {
 	char *token;
 	char *optlist[] = {
@@ -3715,19 +3780,19 @@ void CMD_FakeClick(F_CMD_ARGS)
 	unsigned int mask = 0;
 	Window root = Scr.Root;
 	int maxdepth = 0;
+	static char args[128];
+	strncpy(args, action, sizeof(args) - 1);
+
+	/* get the mask of pressed/released buttons/keys */
+	FQueryPointer(
+		dpy, Scr.Root, &root, &JunkRoot, &JunkX, &JunkY, &JunkX,
+		&JunkY, &mask);
 
-	/* get the mask of pressed/released buttons */
-	if (FQueryPointer(
-		    dpy, Scr.Root, &root, &JunkRoot, &JunkX, &JunkY, &JunkX,
-		    &JunkY, &mask) == False)
-	{
-		/* pointer is on a different screen - that's okay here */
-	}
 	token = PeekToken(action, &action);
 	while (token && action)
 	{
 		int index = GetTokenIndex(token, optlist, 0, NULL);
-		int val;
+		int val, depth;
 		XEvent e;
 		Window w;
 		Window child_w;
@@ -3737,13 +3802,9 @@ void CMD_FakeClick(F_CMD_ARGS)
 		int ry = 0;
 		Bool do_unset;
 		long add_mask = 0;
+		KeySym keysym = NoSymbol;
 
 		XFlush(dpy);
-		if (GetIntegerArguments(action, &action, &val, 1) != 1)
-		{
-			/* error */
-			return;
-		}
 		do_unset = True;
 		switch (index)
 		{
@@ -3753,38 +3814,68 @@ void CMD_FakeClick(F_CMD_ARGS)
 			/* fall through */
 		case 2:
 		case 3:
-			/* button press or release */
-			if (val >= 1 && val <= NUMBER_OF_MOUSE_BUTTONS)
+			/* key/button press or release */
+			if (type == FakeMouseEvent)
 			{
-				int depth = 1;
+				if ((GetIntegerArguments(
+					     action, &action, &val, 1) != 1) ||
+				    val < 1 || val > NUMBER_OF_MOUSE_BUTTONS)
+				{
+					fvwm_msg(
+						ERR, "__fake_event",
+						"Invalid button specifier in"
+						" \"%s\" for FakeClick.", args);
+					return; /* error */
+				}
+			}
+			else /* type == FakeKeyEvent */
+			{
+				char *key = PeekToken(action, &action);
+				if (key == NULL)
+				{
+					fvwm_msg(
+						ERR, "__fake_event",
+						"No keysym specifier in \"%s\""
+						" for FakeKeypress.", args);
+					return;
+				}
 
-				w = None;
-				child_w = root;
-				for (depth = 1; depth != maxdepth &&
-					     w != child_w && child_w != None;
-				     depth++)
+				// Do *NOT* use FvwmStringToKeysym() as it is
+				// case insensitive.
+				keysym = XStringToKeysym(key);
+				if (keysym == NoSymbol)
 				{
-					w = child_w;
-					if (FQueryPointer(
-						    dpy, w, &root, &child_w,
-						    &rx, &ry, &x, &y,
-						    &JunkMask) == False)
-					{
-						/* pointer is on a different
-						 * screen - that's okay here */
-					}
+					fvwm_msg(
+						ERR, "__fake_event",
+						"Invalid keysym specifier (%s)"
+						" in \"%s\" for FakeKeypress.",
+						key, args);
+					return;
 				}
-				if (do_unset)
+			}
+
+			w = None;
+			child_w = root;
+			for (depth = 1;
+				 depth != maxdepth &&
+				     w != child_w && child_w != None;
+				 depth++)
+			{
+				w = child_w;
+				if (FQueryPointer(
+						dpy, w, &root, &child_w,
+						&rx, &ry, &x, &y,
+						&JunkMask) == False)
 				{
-					e.type = ButtonRelease;
-					add_mask = ButtonPressMask;
-				}
-				else
-				{
-					e.type = ButtonPress;
-					add_mask = ButtonPressMask |
-						ButtonReleaseMask;
+					/* pointer is on a different
+					 * screen - that's okay here */
 				}
+			}
+
+			if (type == FakeMouseEvent)
+			{
+				e.type = (do_unset) ?
+					ButtonRelease : ButtonPress;
 				e.xbutton.display = dpy;
 				e.xbutton.window = w;
 				e.xbutton.subwindow = None;
@@ -3797,10 +3888,11 @@ void CMD_FakeClick(F_CMD_ARGS)
 				e.xbutton.button = val;
 				e.xbutton.state = mask;
 				e.xbutton.same_screen = (Scr.Root == root);
-				FSendEvent(
-					dpy, PointerWindow, True,
-					SubstructureNotifyMask | add_mask, &e);
-				XFlush(dpy);
+				/* SS: I think this mask handling code is buggy.
+				 * The value of <mask> is overridden during a
+				 * "wait" operation. Also why are we only using
+				 * Button1Mask? What if the user has requested
+				 * a FakeClick using some other button? */
 				if (do_unset)
 				{
 					mask &= ~(Button1Mask << (val - 1));
@@ -3809,37 +3901,74 @@ void CMD_FakeClick(F_CMD_ARGS)
 				{
 					mask |= (Button1Mask << (val - 1));
 				}
+				add_mask = (do_unset) ?
+					ButtonPressMask : ButtonReleaseMask;
 			}
 			else
 			{
-				/* error */
-				return;
+				/* type == FakeKeyEvent */
+				e.type = (do_unset ? KeyRelease : KeyPress);
+				e.xkey.display = dpy;
+				e.xkey.subwindow = None;
+				e.xkey.root = root;
+				e.xkey.time = fev_get_evtime();
+				e.xkey.x = x;
+				e.xkey.y = y;
+				e.xkey.x_root = rx;
+				e.xkey.y_root = ry;
+				e.xkey.same_screen = (Scr.Root == root);
+
+				w = e.xkey.window = exc->w.w;
+
+				if (FKeysymToKeycode(
+					    dpy, keysym, &(e.xkey.keycode),
+					    &(e.xkey.state)) != True)
+				{
+					fvwm_msg(DBG, "__fake_event",
+						"FKeysymToKeycode failed");
+					return;
+				}
+				e.xkey.state |= mask;
+				add_mask = (do_unset) ?
+					KeyReleaseMask : KeyPressMask;
 			}
+			FSendEvent(dpy, w, True,
+				SubstructureNotifyMask | add_mask, &e);
+			XFlush(dpy);
 			break;
 		case 4:
 		case 5:
 			/* wait */
-			if (val > 0 && val <= 1000000)
+			if ((GetIntegerArguments(
+				     action, &action, &val, 1) != 1) ||
+			    val <= 0 || val > 1000000)
 			{
-				usleep(1000 * val);
-				if (FQueryPointer(
-					    dpy, Scr.Root, &root, &JunkRoot,
-					    &JunkX, &JunkY, &JunkX, &JunkY,
-					    &mask) == False)
-				{
-					/* pointer is on a different screen -
-					 * that's okay here */
-				}
-			}
-			else
-			{
-				/* error */
+				fvwm_msg(ERR, "__fake_event",
+					"Invalid wait value in \"%s\"", args);
 				return;
 			}
+
+			usleep(1000 * val);
+			if (FQueryPointer(
+					dpy, Scr.Root, &root, &JunkRoot,
+					&JunkX, &JunkY, &JunkX, &JunkY,
+					&mask) == False)
+			{
+				/* pointer is on a different screen -
+				 * that's okay here */
+			}
 			break;
 		case 6:
 		case 7:
 			/* set modifier */
+			if (GetIntegerArguments(action, &action, &val, 1) != 1)
+			{
+				fvwm_msg(
+					ERR, "__fake_event",
+					"Invalid modifier value in \"%s\"",
+					args);
+				return;
+			}
 			do_unset = False;
 			if (val < 0)
 			{
@@ -3867,6 +3996,8 @@ void CMD_FakeClick(F_CMD_ARGS)
 				/* error */
 				return;
 			}
+			/* SS: Could be buggy if a "modifier" operation
+			 * preceeds a "wait" operation. */
 			if (do_unset)
 			{
 				mask &= ~val;
@@ -3879,10 +4010,17 @@ void CMD_FakeClick(F_CMD_ARGS)
 		case 8:
 		case 9:
 			/* new max depth */
+			if (GetIntegerArguments(action, &action, &val, 1) != 1)
+			{
+				fvwm_msg(ERR, "__fake_event",
+					"Invalid depth value in \"%s\"", args);
+				return;
+			}
 			maxdepth = val;
 			break;
 		default:
-			/* error */
+			fvwm_msg(ERR, "__fake_event",
+				"Invalid command (%s) in \"%s\"", token, args);
 			return;
 		}
 		if (action)
@@ -3894,6 +4032,20 @@ void CMD_FakeClick(F_CMD_ARGS)
 	return;
 }
 
+void CMD_FakeClick(F_CMD_ARGS)
+{
+	__fake_event(F_PASS_ARGS, FakeMouseEvent);
+
+	return;
+}
+
+void CMD_FakeKeypress(F_CMD_ARGS)
+{
+	__fake_event(F_PASS_ARGS, FakeKeyEvent);
+
+	return;
+}
+
 /* A function to handle stroke (olicha Nov 11, 1999) */
 #ifdef HAVE_STROKE
 void CMD_StrokeFunc(F_CMD_ARGS)
