@@ -14,13 +14,15 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* ---------------------------- included header files ----------------------- */
+/* ---------------------------- included header files ---------------------- */
 
 #include "config.h"
 
 #include <stdio.h>
 
 #include "libs/fvwmlib.h"
+#include "libs/charmap.h"
+#include "libs/wcontext.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "execcontext.h"
@@ -31,25 +33,25 @@
 #include "borders.h"
 #include "icons.h"
 
-/* ---------------------------- local definitions --------------------------- */
+/* ---------------------------- local definitions -------------------------- */
 
-/* ---------------------------- local macros -------------------------------- */
+/* ---------------------------- local macros ------------------------------- */
 
-/* ---------------------------- imports ------------------------------------- */
+/* ---------------------------- imports ------------------------------------ */
 
-/* ---------------------------- included code files ------------------------- */
+/* ---------------------------- included code files ------------------------ */
 
-/* ---------------------------- local types --------------------------------- */
+/* ---------------------------- local types -------------------------------- */
 
-/* ---------------------------- forward declarations ------------------------ */
+/* ---------------------------- forward declarations ----------------------- */
 
-/* ---------------------------- local variables ----------------------------- */
+/* ---------------------------- local variables ---------------------------- */
 
-/* ---------------------------- exported variables (globals) ---------------- */
+/* ---------------------------- exported variables (globals) --------------- */
 
-/* ---------------------------- local functions ----------------------------- */
+/* ---------------------------- local functions ---------------------------- */
 
-/* ---------------------------- interface functions ------------------------- */
+/* ---------------------------- interface functions ------------------------ */
 
 /* Removes decorations from the source rectangle and moves it according to the
  * gravity specification. */
@@ -223,7 +225,7 @@ Bool get_title_button_geometry(
 }
 
 void get_title_font_size_and_offset(
-	FvwmWindow *fw, direction_type title_dir,
+	FvwmWindow *fw, direction_t title_dir,
 	Bool is_left_title_rotated_cw, Bool is_right_title_rotated_cw,
 	Bool is_top_title_rotated, Bool is_bottom_title_rotated,
 	int *size, int *offset)
@@ -233,7 +235,7 @@ void get_title_font_size_and_offset(
 	int font_size;
 	int min_offset;
 	Bool is_rotated_cw, is_rotated;
-	rotation_type draw_rotation;
+	rotation_t draw_rotation;
 
 	/* adjust font offset according to height specified in title style */
 	decor_size = fw->decor->title_height;
@@ -381,9 +383,9 @@ void get_shaded_geometry(
 
 void get_shaded_geometry_with_dir(
 	FvwmWindow *fw, rectangle *small_g, rectangle *big_g,
-	direction_type shade_dir)
+	direction_t shade_dir)
 {
-	direction_type old_shade_dir;
+	direction_t old_shade_dir;
 
 	old_shade_dir = SHADED_DIR(fw);
 	SET_SHADED_DIR(fw, shade_dir);
@@ -504,10 +506,12 @@ void set_window_border_size(
 	if (used_width <= 0)
 	{
 		fw->boundary_width = 0;
+		fw->unshaped_boundary_width = 0;
 	}
 	else
 	{
-		fw->boundary_width = used_width;
+		fw->unshaped_boundary_width = used_width;
+		fw->boundary_width = (fw->wShaped) ? 0 : used_width;
 	}
 
 	return;
@@ -647,7 +651,7 @@ void maximize_adjust_offset(FvwmWindow *fw)
 	return;
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      constrain_size - adjust the given width and height to account for the
@@ -655,8 +659,8 @@ void maximize_adjust_offset(FvwmWindow *fw)
  *
  *      The general algorithm, especially the aspect ratio stuff, is
  *      borrowed from uwm's CheckConsistency routine.
-*
-***********************************************************************/
+ *
+ */
 #define MAKEMULT(a,b) ((b==1) ? (a) : (((int)((a)/(b))) * (b)) )
 void constrain_size(
 	FvwmWindow *fw, const XEvent *e, unsigned int *widthp,
@@ -1265,5 +1269,32 @@ void resize_icon_title_height(FvwmWindow *fw, int dh)
 	return;
 }
 
-/* ---------------------------- builtin commands ---------------------------- */
+void get_page_offset_check_visible(
+	int *ret_page_x, int *ret_page_y, FvwmWindow *fw)
+{
+	if (IsRectangleOnThisPage(&fw->frame_g, fw->Desk))
+	{
+		/* maximize on visible page if any part of the window is
+		 * visible */
+		*ret_page_x = 0;
+		*ret_page_y = 0;
+	}
+	else
+	{
+		int xoff = Scr.Vx % Scr.MyDisplayWidth;
+		int yoff = Scr.Vy % Scr.MyDisplayHeight;
+
+		/* maximize on the page where the center of the window is */
+		*ret_page_x = truncate_to_multiple(
+			fw->frame_g.x + fw->frame_g.width / 2 + xoff,
+			Scr.MyDisplayWidth) - xoff;
+		*ret_page_y = truncate_to_multiple(
+			fw->frame_g.y + fw->frame_g.height / 2 + yoff,
+			Scr.MyDisplayHeight) - yoff;
+	}
+
+	return;
+}
+
+/* ---------------------------- builtin commands --------------------------- */
 
