@@ -14,12 +14,14 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* ---------------------------- included header files ----------------------- */
+/* ---------------------------- included header files ---------------------- */
 
 #include "config.h"
 #include <stdio.h>
 
 #include "libs/fvwmlib.h"
+#include "libs/charmap.h"
+#include "libs/wcontext.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "execcontext.h"
@@ -43,25 +45,25 @@
 #include "stack.h"
 #include "icons.h"
 
-/* ---------------------------- local definitions --------------------------- */
+/* ---------------------------- local definitions -------------------------- */
 
-/* ---------------------------- local macros -------------------------------- */
+/* ---------------------------- local macros ------------------------------- */
 
-/* ---------------------------- imports ------------------------------------- */
+/* ---------------------------- imports ------------------------------------ */
 
-/* ---------------------------- included code files ------------------------- */
+/* ---------------------------- included code files ------------------------ */
 
-/* ---------------------------- local types --------------------------------- */
+/* ---------------------------- local types -------------------------------- */
 
-/* ---------------------------- forward declarations ------------------------ */
+/* ---------------------------- forward declarations ----------------------- */
 
-/* ---------------------------- local variables ----------------------------- */
+/* ---------------------------- local variables ---------------------------- */
 
-/* ---------------------------- exported variables (globals) ---------------- */
+/* ---------------------------- exported variables (globals) --------------- */
 
-/* ---------------------------- local functions ----------------------------- */
+/* ---------------------------- local functions ---------------------------- */
 
-/* ---------------------------- interface functions ------------------------- */
+/* ---------------------------- interface functions ------------------------ */
 
 static void init_style(
 	FvwmWindow *old_t, FvwmWindow *t, window_style *pstyle,
@@ -92,7 +94,7 @@ static void apply_window_updates(
 	{
 		setup_focus_policy(t);
 		if (t == focus_w &&
-		    fpol_query_allow_user_focus(&FW_FOCUS_POLICY(t)))
+		    !fpol_query_allow_user_focus(&FW_FOCUS_POLICY(t)))
 		{
 			focus_w = NULL;
 			if (Scr.Hilite == t)
@@ -190,8 +192,7 @@ static void apply_window_updates(
 		EWMH_SetVisibleName(t, True);
 	}
 
-	if (flags->do_update_window_font ||
-	    flags->do_update_window_font_height)
+	if (flags->do_update_window_font || flags->do_update_window_font_height)
 	{
 		if (!is_style_initialised)
 		{
@@ -276,8 +277,8 @@ static void apply_window_updates(
 				gravity_add_decoration(
 					NorthWestGravity, t, &t->max_g,
 					&naked_g);
-				/* prevent random paging when unmaximizing after
-				 * e.g.the border width has changed */
+				/* prevent random paging when unmaximizing
+				 * after e.g. the border width has changed */
 				new_off_x = t->normal_g.x - t->max_g.x;
 				new_off_y = t->normal_g.y - t->max_g.y;
 				t->max_offset.x += new_off_x - off_x;
@@ -323,52 +324,6 @@ static void apply_window_updates(
 			flags->do_redraw_decoration = True;
 		}
 	}
-	if (0 && flags->do_update_title_dir)
-	{
-		size_borders b_old;
-		size_borders b_new;
-		rectangle unshaded_g;
-		int dw;
-		int dh;
-
-		get_unshaded_geometry(t, &unshaded_g);
-		get_window_borders(t, &b_old);
-		SET_TITLE_DIR(t, S_TITLE_DIR(SCF(*pstyle)));
-		setup_title_geometry(t, pstyle);
-		get_window_borders(t, &b_new);
-		dw = b_new.total_size.width - b_old.total_size.width;
-		dh = b_new.total_size.height - b_old.total_size.height;
-
-		frame_g = t->normal_g;
-		gravity_resize(t->hints.win_gravity, &frame_g, dw, dh);
-		gravity_constrain_size(t->hints.win_gravity, t, &frame_g, 0);
-		t->normal_g = frame_g;
-		if (IS_MAXIMIZED(t))
-		{
-			frame_g = t->max_g;
-			gravity_resize(
-				t->hints.win_gravity, &frame_g, dw, dh);
-			gravity_constrain_size(
-				t->hints.win_gravity, t, &frame_g,
-				CS_UPDATE_MAX_DEFECT);
-			t->max_g = frame_g;
-		}
-		if (IS_SHADED(t))
-		{
-			get_shaded_geometry(t, &frame_g, &unshaded_g);
-		}
-		else if (IS_MAXIMIZED(t))
-		{
-			get_relative_geometry(&frame_g, &t->max_g);
-		}
-		else
-		{
-			get_relative_geometry(&frame_g, &t->normal_g);
-		}
-
-		flags->do_setup_frame = True;
-		flags->do_redraw_decoration = True;
-	}
 	if (flags->do_resize_window)
 	{
 		rectangle old_g;
@@ -509,7 +464,7 @@ static void apply_window_updates(
 	{
 		if (IS_ICONIFIED(t))
 		{
-			initial_window_options_type win_opts;
+			initial_window_options_t win_opts;
 
 			memset(&win_opts, 0, sizeof(win_opts));
 			SET_ICONIFIED(t, 0);
@@ -568,14 +523,22 @@ static void apply_window_updates(
 			if (t->ewmh_hint_layer > 0 &&
 			    t->layer != t->ewmh_hint_layer)
 			{
+				t->ewmh_normal_layer = t->layer;
 				new_layer(t, t->ewmh_hint_layer);
 			}
 		}
 		else
 		{
-			if (t->ewmh_hint_layer > 0)
+			if (t->ewmh_hint_layer > 0 && t->ewmh_normal_layer)
 			{
-				new_layer(t, Scr.DefaultLayer);
+				if (t->ewmh_normal_layer)
+				{
+					new_layer(t, t->ewmh_normal_layer);
+				}
+				else
+				{
+					new_layer(t, Scr.DefaultLayer);
+				}
 			}
 		}
 	}
@@ -602,11 +565,30 @@ static void apply_window_updates(
 		}
 	}
 	t->shade_anim_steps = pstyle->shade_anim_steps;
+	if (flags->do_update_cr_motion_method)
+	{
+		switch (SCR_MOTION_METHOD(&pstyle->flags))
+		{
+		case WS_CR_MOTION_METHOD_AUTO:
+			if (WAS_CR_MOTION_METHOD_DETECTED(t))
+			{
+				/* method was already detected, keep it */
+				break;
+			}
+			/* fall through */
+		case WS_CR_MOTION_METHOD_USE_GRAV:
+		case WS_CR_MOTION_METHOD_STATIC_GRAV:
+			SET_CR_MOTION_METHOD(
+				t, SCR_MOTION_METHOD(&pstyle->flags));
+			SET_CR_MOTION_METHOD_DETECTED(t, 0);
+			break;
+		}
+	}
 
 	return;
 }
 
-/* ---------------------------- builtin commands ---------------------------- */
+/* ---------------------------- builtin commands --------------------------- */
 
 /* takes only care of destroying windows that have to go away. */
 void destroy_scheduled_windows(void)
