@@ -1,17 +1,4 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+/* -*-c-*- */
 
 #ifndef _WINDOW_FLAGS_
 #define _WINDOW_FLAGS_
@@ -73,7 +60,7 @@
 #define SET_TITLE_DIR(fw,x) \
 	((fw)->flags.common.title_dir = x)
 #define SETM_TITLE_DIR(fw,x) \
-	(fw)->flag_mask.common.title_dir = DIR_MAJOR_MASK * !!(x)
+	(fw)->flag_mask.common.title_dir = ((x) ? DIR_MAJOR_MASK : 0)
 #define HAS_VERTICAL_TITLE(fw) \
 	(HAS_TITLE_DIR(fw,DIR_W) || HAS_TITLE_DIR(fw,DIR_E))
 #define HAS_STIPPLED_TITLE(fw) \
@@ -549,6 +536,18 @@
 	(fw)->flags.is_window_font_loaded = !!(x)
 #define SETM_WINDOW_FONT_LOADED(fw,x) \
 	(fw)->flag_mask.is_window_font_loaded = !!(x)
+#define CR_MOTION_METHOD(fw) \
+	((fw)->flags.cr_motion_method)
+#define SET_CR_MOTION_METHOD(fw,x) \
+	(fw)->flags.cr_motion_method = ((x) & CR_MOTION_METHOD_MASK)
+#define SETM_CR_MOTION_METHOD(fw,x) \
+	(fw)->flag_mask.cr_motion_method = ((x) ? CR_MOTION_METHOD_MASK : 0)
+#define WAS_CR_MOTION_METHOD_DETECTED(fw) \
+	((fw)->flags.was_cr_motion_method_detected)
+#define SET_CR_MOTION_METHOD_DETECTED(fw,x) \
+	(fw)->flags.was_cr_motion_method_detected = !!(x)
+#define SETM_CR_MOTION_METHOD_DETECTED(fw,x) \
+	(fw)->flag_mask.was_cr_motion_method_detected = !!(x)
 #define WM_DELETES_WINDOW(fw) \
 	((fw)->flags.does_wm_delete_window)
 #define SET_WM_DELETES_WINDOW(fw,x) \
@@ -633,12 +632,24 @@
 	(fw)->flags.has_ewmh_mini_icon = !!(x)
 #define SETM_HAS_EWMH_MINI_ICON(fw,x) \
 	(fw)->flag_mask.has_ewmh_mini_icon = !!(x)
+#define HAS_EWMH_WM_PID(fw) \
+	((fw)->flags.has_ewmh_wm_pid)
+#define SET_HAS_EWMH_WM_PID(fw,x) \
+	(fw)->flags.has_ewmh_wm_pid = !!(x)
+#define SETM_HAS_EWMH_WM_PID(fw,x) \
+	(fw)->flag_mask.has_ewmh_wm_pid = !!(x)
 #define IS_EWMH_MODAL(fw) \
 	((fw)->flags.is_ewmh_modal)
 #define SET_EWMH_MODAL(fw,x) \
 	(fw)->flags.is_ewmh_modal = !!(x)
 #define SETM_EWMH_MODAL(fw,x) \
 	(fw)->flag_mask.is_ewmh_modal = !!(x)
+#define IS_EWMH_FULLSCREEN(fw) \
+	((fw)->flags.is_ewmh_fullscreen)
+#define SET_EWMH_FULLSCREEN(fw,x) \
+	(fw)->flags.is_ewmh_fullscreen = !!(x)
+#define SETM_EWMH_FULLSCREEN(fw,x) \
+	(fw)->flag_mask.is_ewmh_fullscreen = !!(x)
 #define SET_HAS_EWMH_INIT_FULLSCREEN_STATE(fw,x) \
 	(fw)->flags.has_ewmh_init_fullscreen_state = (x)
 #define SETM_HAS_EWMH_INIT_FULLSCREEN_STATE(fw,x) \
