@@ -189,7 +189,6 @@ int FlocaleChar2bOneCharToUtf8(XChar2b c, char *buf)
 
 /* return number of bytes of character at current position
    (pointed to by str) */
-static
 int FlocaleStringNumberOfBytes(FlocaleFont *flf, const unsigned char *str)
 {
         int bytes = 0;
@@ -230,10 +229,8 @@ int FlocaleStringNumberOfBytes(FlocaleFont *flf, const unsigned char *str)
 	return bytes;
 }
 
-
 /* given a string, font specifying its locale and a byte offset gives
    character offset */
-static
 int FlocaleStringByteToCharOffset(FlocaleFont *flf, const unsigned char *str,
 				  int offset)
 {
@@ -254,7 +251,6 @@ int FlocaleStringByteToCharOffset(FlocaleFont *flf, const unsigned char *str,
 
 /* like above but reversed, ie. return byte offset corresponding to given 
    charater offset */
-static
 int FlocaleStringCharToByteOffset(FlocaleFont *flf, const unsigned char *str,
 				  int coffset)
 {
@@ -273,6 +269,16 @@ int FlocaleStringCharToByteOffset(FlocaleFont *flf, const unsigned char *str,
 	return offset;
 }
 
+/* return length of string in characters */
+int FlocaleStringCharLength(FlocaleFont *flf, const unsigned char *str)
+{
+	int i, len;
+	int str_len = strlen(str);
+	for(i = 0, len = 0 ; i < str_len ; 
+	    i += FlocaleStringNumberOfBytes(flf, str+i), len++);
+	return len;
+}
+
 static
 XChar2b *FlocaleUtf8ToUnicodeStr2b(unsigned char *str, int len, int *nl)
 {
@@ -415,6 +421,7 @@ char *FlocaleEncodeString(
 {
 	char *str1, *str2, *str3;
 	int len1 = len, len2;
+	int i;
 	Bool do_iconv = True;
 	const char *bidi_charset;
 
@@ -491,6 +498,26 @@ char *FlocaleEncodeString(
 	{
 	        str2 = str1;
 		len1 = len;
+		/* initialise array with composing characters (empty) */
+		if(comb_chars != NULL && *comb_chars == NULL)
+		{
+			*comb_chars = (superimpose_char_t *)
+				safemalloc(sizeof(superimpose_char_t));
+			(*comb_chars)[0].position = -1;
+ 			(*comb_chars)[0].c.byte1 = 0;
+ 			(*comb_chars)[0].c.byte2 = 0;
+		}
+				
+		/* initialise logic to visual mapping here if that is demanded
+		   (this is default when no combining has been done (1-to-1))
+		*/
+		if(l_to_v != NULL && *l_to_v == NULL)
+		{
+			*l_to_v = (int*)safemalloc((len + 1) * sizeof(int));
+			for(i = 0 ; i < len ; i++)
+				(*l_to_v)[i] = i;
+			(*l_to_v)[len] = -1;
+		}
 	}
 
 	if (FlocaleGetBidiCharset(dpy, flf->str_fc) != NULL &&
@@ -1812,7 +1839,8 @@ void FlocaleDrawString(
 	}
 
 	/* for superimposition calculate the character positions in pixels */
-	if(comb_chars != NULL)
+	if(comb_chars != NULL && (comb_chars[0].c.byte1 != 0 ||
+				  comb_chars[0].c.byte2 != 0))
 	{
 		/* the second condition is actually redundant, 
 		   but there for clarity, 
@@ -2043,7 +2071,8 @@ void FlocaleDrawString(
 	if(comb_chars != NULL)
 	{
 	        free(comb_chars);
-		free(pixel_pos);
+		if(pixel_pos)
+			free(pixel_pos);
 	}
 
 	return;
@@ -2084,7 +2113,8 @@ void FlocaleDrawUnderline(
 	off1 = FlocaleTextWidth(flf, fws->e_str, voffset) +
 		((voffset == 0)?
 		 FLF_SHADOW_LEFT_SIZE(flf) : - FLF_SHADOW_RIGHT_SIZE(flf) );
-	off2 = FlocaleTextWidth(flf, fws->e_str + voffset, 1) -
+	off2 = FlocaleTextWidth(flf, fws->e_str + voffset, 
+		      FlocaleStringNumberOfBytes(flf, fws->e_str + voffset)) -
 		FLF_SHADOW_WIDTH(flf) - 1 + off1;
 	y = fws->y + 2;
 	x_s = fws->x + off1;
@@ -2093,8 +2123,13 @@ void FlocaleDrawUnderline(
 	/* No shadow */
 	XDrawLine(dpy, fws->win, fws->gc, x_s, y, x_e, y);
 
-	free(fws->e_str);
-	fws->e_str = NULL;
+	/* free encoded string if it isn't the same as input string */
+	if(fws->e_str != fws->str)
+	{
+		free(fws->e_str);
+		fws->e_str = NULL;
+	}
+	
 	if(fws->str2b != NULL)
 	{
 		free(fws->str2b);
@@ -2120,10 +2155,24 @@ int FlocaleTextWidth(FlocaleFont *flf, char *str, int sl)
 		/* a vertical string: nothing to do! */
 		sl = -sl;
 	}
+		
 	/* FIXME */
-	tmp_str = FlocaleEncodeString(
-		     Pdpy, flf, str, &do_free, sl, &new_l, NULL, &comb_chars, 
-		     NULL);
+	/* to avoid eccesive calls iconv (slow in Solaris 8)
+	   don't bother to encode if string is one byte 
+	   when drawing a string this function is used to calculate 
+	   position of each character (for superimposition) */
+	if(sl == 1)
+	{
+		tmp_str = str;
+		new_l = sl;
+		do_free = False;
+	}
+	else
+	{
+		tmp_str = FlocaleEncodeString(
+			   Pdpy, flf, str, &do_free, sl, &new_l, NULL, 
+			   &comb_chars, NULL);
+	}
 	/* if we get zero-length, check to to see if there if there's any
 	   combining chars, if so use an imagninary space as a 
 	   "base character" */
