@@ -1,8 +1,7 @@
 /* -*-c-*- */
 /* Copyright (C) 1993, Robert Nation
- * Copyright (C) 2002  Olivier Chapuis
- *
- * This program is free software; you can redistribute it and/or modify
+ * Copyright (C) 2002  Olivier Chapuis */
+/* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -17,7 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* ---------------------------- included header files ----------------------- */
+/* ---------------------------- included header files ---------------------- */
 
 #include "config.h"
 
@@ -36,7 +35,7 @@
 #include "PictureUtils.h"
 #include "PictureDitherMatrice.h"
 
-/* ---------------------------- local definitions and macro ------------------ */
+/* ---------------------------- local definitions and macro ----------------- */
 
 #define PICTURE_DEBUG_COLORS_ALLOC_FAILURE 0
 
@@ -80,16 +79,16 @@
  * do think that using gamma correction for the colors cubes is a good
  * idea */
 #define USE_GAMMA_CORECTION 0
-/* 2.2 is recommanded by the Poynon colors FAQ, some others suggest 1.5 and 2 
+/* 2.2 is recommanded by the Poynon colors FAQ, some others suggest 1.5 and 2
  * Use float constants!*/
 #define COLOR_GAMMA 1.5
 #define GREY_GAMMA  2.0
 
-/* ---------------------------- imports ------------------------------------- */
+/* ---------------------------- imports ------------------------------------ */
 
-/* ---------------------------- included code files ------------------------- */
+/* ---------------------------- included code files ------------------------ */
 
-/* ---------------------------- local types --------------------------------- */
+/* ---------------------------- local types -------------------------------- */
 
 typedef struct
 {
@@ -114,7 +113,9 @@ typedef struct
 	short d_ng;
 	short d_nb;
 	short d_ngrey_bits;
-       /* info for depth > 8 */
+	/* do we found a pre-allocated pallet ? */
+	Bool pre_allocated_pallet;
+	/* info for depth > 8 */
 	int red_shift;
 	int green_shift;
 	int blue_shift;
@@ -126,48 +127,40 @@ typedef struct
 	unsigned short *green_dither;
 	unsigned short *blue_dither;
 	/* colors allocation function */
-#ifdef __STDC__
-	int (*alloc_color)(
-		Display *dpy, Colormap cmap, XColor *c, Bool is_8);
-	int (*alloc_color_no_limit)(
-		Display *dpy, Colormap cmap, XColor *c, Bool is_8);
-	int (*alloc_color_dither)(
-		Display *dpy, Colormap cmap, XColor *c, int x, int y, Bool is_8);
-#else
 	int (*alloc_color)();
 	int (*alloc_color_no_limit)();
 	int (*alloc_color_dither)();
-#endif
-
-
+	void (*free_colors)();
+	void (*free_colors_no_limit)();
 } PColorsInfo;
 
 typedef struct {
-    int cols_index;
-    long closeness;
-}      CloseColor;
+	int cols_index;
+	long closeness;
+} CloseColor;
 
-/* ---------------------------- forward declarations ------------------------ */
+/* ---------------------------- forward declarations ----------------------- */
 
-/* ---------------------------- local variables ----------------------------- */
+/* ---------------------------- local variables ---------------------------- */
 
 static int PColorLimit = 0;
 static PColor *Pct = NULL;
+static PColor *Pac = NULL;
 static short *PMappingTable = NULL;
 static short *PDitherMappingTable = NULL;
 static Bool PStrictColorLimit = 0;
 static Bool PAllocTable = 0;
 static PColorsInfo Pcsi = {
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL, NULL,
-	NULL, NULL};
+	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL, NULL,
+	NULL, NULL, NULL, NULL};
 
-/* ---------------------------- exported variables (globals) ---------------- */
+/* ---------------------------- exported variables (globals) --------------- */
 
-/* ---------------------------- local functions ----------------------------- */
+/* ---------------------------- local functions ---------------------------- */
 
-/* ***************************************************************************
+/*
  * get shift and prec from a mask
- * ***************************************************************************/
+ */
 static
 void decompose_mask(
 	unsigned long mask, int *shift, int *prec)
@@ -188,10 +181,10 @@ void decompose_mask(
 	}
 }
 
-/* ***************************************************************************
+/*
  * color allocation in the colormap. strongly inspired by SetCloseColor from
  * the Xpm library (depth <= 8)
- * ***************************************************************************/
+ */
 
 static int
 closeness_cmp(const void *a, const void *b)
@@ -270,9 +263,9 @@ int alloc_color_in_cmap(XColor *c, Bool force)
 	return 0;
 }
 
-/* ***************************************************************************
+/*
  * dithering
- * ***************************************************************************/
+ */
 
 static
 int my_dither(int x, int y, XColor *c)
@@ -303,7 +296,7 @@ int my_dither(int x, int y, XColor *c)
 		/* color cube */
 		int dith, rs, gs, bs, gb, b;
 		int tr,tb,tg;
-		
+
 		rs = Pcsi.d_nr - 1;
 		gs = Pcsi.d_ng - 1;
 		bs = Pcsi.d_nb - 1;
@@ -436,9 +429,9 @@ int my_dither_depth_15_16_init(void)
 	return 1;
 }
 
-/* ***************************************************************************
+/*
  * Color allocation in the "palette"
- * ***************************************************************************/
+ */
 
 static
 int alloc_color_in_pct(XColor *c, int index)
@@ -572,11 +565,11 @@ int get_color_index(int r, int g, int b, int is_8)
 	return index;
 }
 
-/* ***************************************************************************
- * colors allocator
- * ***************************************************************************/
+/*
+ * Main colors allocator
+ */
 static
-int alloc_color_static(Display *dpy, Colormap cmap, XColor *c, Bool is_8)
+int alloc_color_proportion(Display *dpy, Colormap cmap, XColor *c)
 {
 	c->pixel = (Pixel)(
 		((c->red   >> (16 - Pcsi.red_prec))<< Pcsi.red_shift) +
@@ -587,15 +580,10 @@ int alloc_color_static(Display *dpy, Colormap cmap, XColor *c, Bool is_8)
 }
 
 static
-int alloc_color_static_dither(
-	Display *dpy, Colormap cmap, XColor *c, int x, int y, Bool is_8)
+int alloc_color_proportion_dither(
+	Display *dpy, Colormap cmap, XColor *c, int x, int y)
 {
-	if (!is_8)
-	{
-		c->red = c->red >> 8;
-		c->green = c->green >> 8;
-		c->blue = c->blue >> 8;
-	}
+	/* 8 bit colors !! */
 	c->red = Pcsi.red_dither[
 		(((x + 0) & 0x3) << 10) | ((y & 0x3) << 8) |
 		((c->red) & 0xff)] * 257;
@@ -614,7 +602,9 @@ int alloc_color_static_dither(
 	return 1;
 }
 
-int alloc_color_static_grey(Display *dpy, Colormap cmap, XColor *c, Bool is_8)
+static
+int alloc_color_proportion_grey(
+	Display *dpy, Colormap cmap, XColor *c)
 {
 	/* FIXME: is this ok in general? */
 	c->pixel = ((c->red + c->green + c->blue)/3);
@@ -625,55 +615,131 @@ int alloc_color_static_grey(Display *dpy, Colormap cmap, XColor *c, Bool is_8)
 	return 1;
 }
 
-int alloc_color_in_table(Display *dpy, Colormap cmap, XColor *c, Bool is_8)
+static
+int alloc_color_in_table(Display *dpy, Colormap cmap, XColor *c)
 {
 
 	int index = get_color_index(c->red,c->green,c->blue, False);
 	return alloc_color_in_pct(c, index);
 }
 
+static
 int alloc_color_in_table_dither(
-	Display *dpy, Colormap cmap, XColor *c, int x, int y, Bool is_8)
+	Display *dpy, Colormap cmap, XColor *c, int x, int y)
 {
 	int index;
-
-	if (!is_8)
-	{
-		c->red = c->red >> 8;
-		c->green = c->green >> 8;
-		c->blue = c->blue >> 8;
-	}
+	/* 8 bit colors !! */
 	index = my_dither(x, y, c);
 	return alloc_color_in_pct(c, index);
 }
 
+static
 int alloc_color_dynamic_no_limit(
-	Display *dpy, Colormap cmap, XColor *c, Bool is_8)
+	Display *dpy, Colormap cmap, XColor *c)
 {
+	int r = 0;
+
 	if (XAllocColor(dpy, cmap, c))
 	{
-		return 1;
+		r = 1;
 	}
-	if (!alloc_color_in_cmap(c, False))
+	else if (!alloc_color_in_cmap(c, False))
 	{
-		int status;
-
 		XGrabServer(dpy);
-		status = alloc_color_in_cmap(c, True);
+		r = alloc_color_in_cmap(c, True);
 		XUngrabServer(dpy);
-		return status;
 	}
 	else
 	{
-		return 1;
+		r = 1;
 	}
-	return 0;
+	if (r && Pac != NULL && (c->pixel <= (1 << Pdepth) /* always true*/))
+	{
+		Pac[c->pixel].alloc_count++;
+		Pac[c->pixel].color.red = c->red;
+		Pac[c->pixel].color.green = c->green;
+		Pac[c->pixel].color.blue = c->blue;
+		Pac[c->pixel].color.pixel = c->pixel;
+	}
+	return r;
 }
 
-/* ***************************************************************************
+static
+int alloc_color_x(
+	Display *dpy, Colormap cmap, XColor *c)
+{
+	return XAllocColor(dpy, cmap, c);
+}
+
+static
+void free_colors_in_table(
+	Display *dpy, Colormap cmap, Pixel *pixels, int n, unsigned long planes,
+	Bool no_limit)
+{
+	Pixel *p;
+	int i,j,do_free;
+	int m = 0;
+
+	if (!Pct || !PUseDynamicColors)
+	{
+		return;
+	}
+
+	p = (Pixel *)safemalloc(n*sizeof(Pixel));
+	for(i= 0; i < n; i++)
+	{
+		do_free = 1;
+		for(j=0; j<PColorLimit; j++)
+		{
+			if (Pct[j].alloc_count &&
+			    Pct[j].alloc_count < 0xffffffff &&
+			    pixels[i] == Pct[j].color.pixel)
+			{
+				(Pct[j].alloc_count)--;
+				if (Pct[j].alloc_count)
+					do_free = 0;
+				break;
+			}
+		}
+		if (do_free)
+		{
+			p[m++] = pixels[i];
+		}
+	}
+	if (m > 0)
+	{
+		XFreeColors(dpy, cmap, p, m, planes);
+	}
+	free(p);
+
+	return;
+}
+
+static
+void free_colors_x(
+	Display *dpy, Colormap cmap, Pixel *pixels, int n, unsigned long planes,
+	Bool no_limit)
+{
+	XFreeColors(dpy, cmap, pixels, n, planes);
+	if (Pac != NULL)
+	{
+		int nbr_colors = (1 << Pdepth);
+		int i;
+
+		for(i= 0; i < n; i++)
+		{
+			if (pixels[i] <= nbr_colors)
+			{
+				Pac[pixels[i]].alloc_count--;
+			}
+		}
+	}
+}
+
+/*
  * local function for building pallet (dynamic colors, private DirectColor
  * cmap)
- * ***************************************************************************/
+ */
 static
 XColor *build_mapping_colors(int nr, int ng, int nb)
 {
@@ -882,7 +948,7 @@ PColor *alloc_color_cube(
 			}
 		}
 	}
-	
+
 	if (ngrey > 0)
 	{
 		for (grey = start_grey; grey < end_grey; grey++)
@@ -1042,13 +1108,14 @@ PColor *alloc_named_ct(int *limit, Bool do_allocate)
 
 static
 void create_mapping_table(
-	int nr, int ng, int nb, int ngrey, int grey_bits, Bool use_named)
+	int nr, int ng, int nb, int ngrey, int grey_bits,
+	Bool non_regular_pallet)
 {
 
 	Pcsi.grey_bits = 0;
 
 	/* initialize dithering colors numbers */
-	if (!use_named)
+	if (!non_regular_pallet)
 	{
 		/* */
 		Pcsi.d_nr = nr;
@@ -1076,15 +1143,22 @@ void create_mapping_table(
 			Pcsi.d_nb = 3;
 			Pcsi.d_ngrey_bits = 0;
 		}
-		else
+		else if (PColorLimit <= 64)
 		{
 			Pcsi.d_nr = 4;
 			Pcsi.d_ng = 4;
 			Pcsi.d_nb = 4;
 			Pcsi.d_ngrey_bits = 0;
 		}
+		else
+		{
+			Pcsi.d_nr = 8;
+			Pcsi.d_ng = 8;
+			Pcsi.d_nb = 8;
+			Pcsi.d_ngrey_bits = 0;
+		}
 		PDitherMappingTable = build_mapping_table(
-			Pcsi.d_nr, Pcsi.d_ng, Pcsi.d_nb, use_named);
+			Pcsi.d_nr, Pcsi.d_ng, Pcsi.d_nb, non_regular_pallet);
 	}
 
 	/* initialize colors number fo index computation */
@@ -1105,7 +1179,7 @@ void create_mapping_table(
 		Pcsi.ngrey = 0;
 		Pcsi.grey_bits = grey_bits;
 	}
-	else if (use_named || (0&&ngrey>0))
+	else if (non_regular_pallet || (0&&ngrey>0))
 	{
 		/* note: using these table with !used_named && ngrey>0 will
 		 * probably leads to faster image loading. But I see nothing
@@ -1126,7 +1200,7 @@ void create_mapping_table(
 			Pcsi.ngrey = 0;
 		}
 		PMappingTable = build_mapping_table(
-			Pcsi.nr, Pcsi.ng, Pcsi.nb, use_named);
+			Pcsi.nr, Pcsi.ng, Pcsi.nb, non_regular_pallet);
 	}
 	else
 	{
@@ -1169,6 +1243,11 @@ void finish_ct_init(
 		env = safemalloc(21+PICTURE_TABLETYPE_LENGHT+1);
 		sprintf(env,"FVWM_COLORTABLE_TYPE=%i",ctt);
 		putenv(env);
+		if (Pdepth <= 8)
+		{
+			Pac = (PColor *)safecalloc(
+				(1 << Pdepth), sizeof(PColor));
+		}
 	}
 
 	if (Pct)
@@ -1189,7 +1268,8 @@ void finish_ct_init(
 #define ANY_GRAY_SCALE (PA_GRAY_SCALE|FVWM_GRAY_SCALE)
 
 static
-int PictureAllocColorTable(char *opt, int call_type, Bool use_my_color_limit)
+int PictureAllocColorTable(
+	PictureColorLimitOption *opt, int call_type, Bool use_my_color_limit)
 {
 	char *envp;
 	int free_colors, nbr_of_color, limit, cc_nbr, i, size;
@@ -1200,14 +1280,14 @@ int PictureAllocColorTable(char *opt, int call_type, Bool use_my_color_limit)
 	int dyn_cl_set = False;
 	int strict_cl_set = False;
 	int alloc_table_set = False;
-	int color_limit; /* not the default at all */
+	int color_limit;
 	int pa_type = (Pvisual->class != GrayScale)? PA_COLOR_CUBE:PA_GRAY_SCALE;
 	int fvwm_type = (Pvisual->class != GrayScale)?
 		FVWM_COLOR_CUBE:FVWM_GRAY_SCALE;
 	int cc[][6] =
 	{
 		/* {nr,ng,nb,ngrey,grey_bits,logic} */
-		/* 3 first for direct colors and Pdepth > 8*/
+		/* 5 first for direct colors and Pdepth > 8*/
 		/* 8192 colors depth 13, a reasonable max for a color table */
 		{16, 32, 16, 0, 0, FVWM_COLOR_CUBE},
 		/* 4096 colors depth 12 */
@@ -1274,9 +1354,14 @@ int PictureAllocColorTable(char *opt, int call_type, Bool use_my_color_limit)
 	};
 
 	cc_nbr = sizeof(cc)/(sizeof(cc[0]));
-	/* by default use dynamic colors */
+
+	/* set up  default */
+	PStrictColorLimit = 0;
 	PUseDynamicColors = 1;
 	PAllocTable = 0;
+	use_named_table = False;
+	color_limit = 0;
+	use_default = True;
 
 	/* use fvwm color limit */
 	if (!use_my_color_limit &&
@@ -1339,7 +1424,7 @@ int PictureAllocColorTable(char *opt, int call_type, Bool use_my_color_limit)
 	color_limit = 0;
 
 	/* parse the color limit env variable */
-	if ((envp = opt) != NULL || (envp = getenv("FVWM_COLORLIMIT")) != NULL)
+	if ((envp = getenv("FVWM_COLORLIMIT")) != NULL)
 	{
 		char *rest, *l;
 
@@ -1398,8 +1483,58 @@ int PictureAllocColorTable(char *opt, int call_type, Bool use_my_color_limit)
 			}
 		}
 	}
+	else if (opt != NULL) /* use the option */
+	{
+		if (opt->color_limit > 0)
+		{
+			use_default = 0;
+			color_limit = opt->color_limit;
+		}
+		if (color_limit == 9 || color_limit == 61)
+		{
+			use_named_table = 1;
+		}
+		if (opt->strict > 0)
+		{
+			strict_cl_set = True;
+			PStrictColorLimit = 1;
+		}
+		else if (opt->strict == 0)
+		{
+			strict_cl_set = True;
+			PStrictColorLimit = 0;
+		}
+		if (opt->use_named_table > 0)
+		{
+			use_named_table = 1;
+		}
+		else if (opt->use_named_table == 0)
+		{
+			use_named_table = 0;
+		}
+		if (opt->not_dynamic > 0)
+		{
+			dyn_cl_set = True;
+			PUseDynamicColors = 0;
+		}
+		else if (opt->not_dynamic == 0)
+		{
+			dyn_cl_set = True;
+			PUseDynamicColors = 0;
+		}
+		if (opt->allocate > 0)
+		{
+			alloc_table_set = True;
+			PAllocTable = 1;
+		}
+		else if (opt->allocate == 0)
+		{
+			alloc_table_set = True;
+			PAllocTable = 0;
+		}
+	}
 
-	if (color_limit == 0)
+	if (color_limit <= 0)
 	{
 		use_default = 1;
 		color_limit = nbr_of_color;
@@ -1420,6 +1555,12 @@ int PictureAllocColorTable(char *opt, int call_type, Bool use_my_color_limit)
 	 * imlib2 try to allocate the 666 cube if this fail it try more
 	 * exotic table (see rend.c and rgba.c) */
 	i = 0;
+	free_colors = 0;
+	if (Pdepth <= 8 && !private_cmap && use_default &&
+	    i < cc_nbr && Pct == NULL && (Pvisual->class & 1))
+	{
+		free_colors = get_nbr_of_free_colors(nbr_of_color);
+	}
 	while(Pdepth <= 8 && !private_cmap && use_default &&
 	      i < cc_nbr && Pct == NULL && (Pvisual->class & 1))
 	{
@@ -1430,7 +1571,6 @@ int PictureAllocColorTable(char *opt, int call_type, Bool use_my_color_limit)
 			i++;
 			continue;
 		}
-		free_colors = get_nbr_of_free_colors(nbr_of_color);
 		if (free_colors <= nbr_of_color - size)
 		{
 			Pct = alloc_color_cube(
@@ -1455,14 +1595,9 @@ int PictureAllocColorTable(char *opt, int call_type, Bool use_my_color_limit)
 	}
 	if (Pct != NULL)
 	{
-		if (!dyn_cl_set)
-		{
-			PUseDynamicColors = 0;
-		}
-		if (!alloc_table_set)
-		{
-			PAllocTable = 1;
-		}
+		PUseDynamicColors = 0;
+		PAllocTable = 1;
+		Pcsi.pre_allocated_pallet = 1;
 		i = i - 1;
 		finish_ct_init(
 			call_type, i, cc[i][0], cc[i][1], cc[i][2], cc[i][3],
@@ -1524,7 +1659,7 @@ int PictureAllocColorTable(char *opt, int call_type, Bool use_my_color_limit)
 				 * limit = 68 4x4x4 + 4
 				 * limit = 64 4x4x4 + 0 */
 			}
-			
+
 		}
 		else if (limit == 128 || limit == 64)
 		{
@@ -1566,19 +1701,9 @@ int PictureAllocColorTable(char *opt, int call_type, Bool use_my_color_limit)
 	{
 		/* humm ... Any way this case should never happen in real life:
 		 * DirectColor default colormap! */
-		if (!dyn_cl_set)
-		{
-			PUseDynamicColors = 0;
-			PAllocTable = 1;
-		}
-		if (!strict_cl_set)
-		{
-			PStrictColorLimit = 1;
-		}
-		if (Pdepth > 8)
-		{
-			PAllocTable = 1;
-		}
+		PUseDynamicColors = 0;
+		PAllocTable = 1;
+		PStrictColorLimit = 1;
 	}
 	if (PAllocTable)
 	{
@@ -1636,13 +1761,14 @@ int PictureAllocColorTable(char *opt, int call_type, Bool use_my_color_limit)
 	{
 		fprintf(stderr,
 			"[FVWM] ERR -- Cannot get Black and White. exiting!\n");
+		exit(2);
 	}
 	return PColorLimit;
 }
 
-/* ***************************************************************************
+/*
  * Allocation of a private DirectColor cmap this is broken for depth > 16
- * ***************************************************************************/
+ */
 static
 Bool alloc_direct_colors(int *limit, Bool use_my_color_limit)
 {
@@ -1710,9 +1836,41 @@ Bool alloc_direct_colors(int *limit, Bool use_my_color_limit)
 	return 1;
 }
 
-/* ***************************************************************************
+/*
+ * Init the table for Static Colors
+ */
+static
+void init_static_colors_table(void)
+{
+	XColor colors[256];
+	int i;
+	int nbr_of_colors = max(256, (1 << Pdepth));
+
+	PColorLimit = nbr_of_colors;
+	Pct = (PColor *)safemalloc((nbr_of_colors+1) * sizeof(PColor));
+	for (i = 0; i < nbr_of_colors; i++)
+	{
+		colors[i].pixel = Pct[i].color.pixel = i;
+	}
+	XQueryColors(Pdpy, Pcmap, colors, nbr_of_colors);
+	for (i = 0; i < nbr_of_colors; i++)
+	{
+		Pct[i].color.red = colors[i].red;
+		Pct[i].color.green = colors[i].green;
+		Pct[i].color.blue = colors[i].blue;
+		Pct[i].alloc_count = 1;
+	}
+	Pct[PColorLimit].color.red = Pct[PColorLimit-1].color.red;
+	Pct[PColorLimit].color.green = Pct[PColorLimit-1].color.green;
+	Pct[PColorLimit].color.blue = Pct[PColorLimit-1].color.blue;
+	Pct[PColorLimit].alloc_count = 1;
+	create_mapping_table(0, 0, 0, 0, 0, True);
+}
+
+
+/*
  * misc local functions
- * ***************************************************************************/
+ */
 static
 void print_colormap(Colormap cmap)
 {
@@ -1733,7 +1891,7 @@ void print_colormap(Colormap cmap)
 	}
 }
 
-/* ---------------------------- interface functions ------------------------- */
+/* ---------------------------- interface functions ------------------------ */
 
 int PictureAllocColor(Display *dpy, Colormap cmap, XColor *c, int no_limit)
 {
@@ -1744,11 +1902,11 @@ int PictureAllocColor(Display *dpy, Colormap cmap, XColor *c, int no_limit)
 
 	if (no_limit)
 	{
-		return Pcsi.alloc_color_no_limit(dpy, cmap, c, False);
+		return Pcsi.alloc_color_no_limit(dpy, cmap, c);
 	}
 	else
 	{
-		return Pcsi.alloc_color(dpy, cmap, c, False);
+		return Pcsi.alloc_color(dpy, cmap, c);
 	}
 	return 0;
 }
@@ -1761,7 +1919,13 @@ int PictureAllocColorAllProp(
 
 	if (!no_limit && do_dither && Pcsi.alloc_color_dither != NULL)
 	{
-		return Pcsi.alloc_color_dither(dpy, cmap, c, x, y, is_8);
+		if (!is_8)
+		{
+			c->red = c->red >> 8;
+			c->green = c->green >> 8;
+			c->blue = c->blue >> 8;
+		}
+		return Pcsi.alloc_color_dither(dpy, cmap, c, x, y);
 	}
 	else
 	{
@@ -1776,55 +1940,158 @@ int PictureAllocColorAllProp(
 	return 0;
 }
 
+int PictureAllocColorImage(
+	Display *dpy, PictureImageColorAllocator *pica, XColor *c, int x, int y)
+{
+	int r;
+
+	r = PictureAllocColorAllProp(
+		dpy, pica->cmap, c, x, y,
+		pica->no_limit, pica->is_8, pica->dither);
+	if (r && pica->pixels_table != NULL && pica->pixels_table_size &&
+	    c->pixel < pica->pixels_table_size)
+	{
+		pica->pixels_table[c->pixel]++;
+	}
+	return r;
+}
+
+PictureImageColorAllocator *PictureOpenImageColorAllocator(
+	Display *dpy, Colormap cmap, int x, int y, Bool no_limit,
+	Bool do_not_save_pixels, int dither, Bool is_8)
+{
+	PictureImageColorAllocator *pica;
+	Bool do_save_pixels = False;
+
+	pica = (PictureImageColorAllocator *)safemalloc(
+		sizeof(PictureImageColorAllocator));
+	if (Pdepth <= 8 && !do_not_save_pixels && (Pvisual->class & 1) &&
+	    ((PUseDynamicColors && Pct) || no_limit))
+	{
+		int s =  1 << Pdepth;
+		pica->pixels_table = (unsigned long *)safecalloc(
+			s, sizeof(unsigned long));
+		pica->pixels_table_size = s;
+		do_save_pixels = True;
+	}
+	if (!do_save_pixels)
+	{
+		pica->pixels_table = NULL;
+		pica->pixels_table_size = 0;
+	}
+	pica->is_8 = is_8;
+	if (dither && Pdepth <= 16)
+	{
+		pica->dither = dither;
+	}
+	else
+	{
+		pica->dither = dither;
+	}
+	pica->no_limit = no_limit;
+	pica->cmap = cmap;
+	return pica;
+}
+
+void PictureCloseImageColorAllocator(
+	Display *dpy, PictureImageColorAllocator *pica, int *nalloc_pixels,
+	Pixel **alloc_pixels, Bool *no_limit)
+{
+	if (nalloc_pixels)
+	{
+		*nalloc_pixels = 0;
+	}
+	if (alloc_pixels != NULL)
+	{
+		*alloc_pixels = NULL;
+	}
+	if (no_limit != NULL)
+	{
+		*no_limit = 0;
+	}
+	if (pica->pixels_table)
+	{
+		int i,j;
+		int k = 0, l = 0, np = 0;
+		int free_num = 0;
+		Pixel *free_pixels = NULL;
+		Pixel *save_pixels = NULL;
+
+		for(i = 0; i < pica->pixels_table_size; i++)
+		{
+			if (pica->pixels_table[i])
+			{
+				free_num += (pica->pixels_table[i]-1);
+				np++;
+			}
+		}
+		if (free_num)
+		{
+			free_pixels = (Pixel *)safemalloc(
+				free_num * sizeof(Pixel));
+		}
+		if (np && nalloc_pixels != NULL && alloc_pixels != NULL)
+		{
+			save_pixels = (Pixel *)safemalloc(np * sizeof(Pixel));
+		}
+		for(i = 0; i < pica->pixels_table_size; i++)
+		{
+			if (pica->pixels_table[i])
+			{
+				if (save_pixels)
+				{
+					save_pixels[k++] = i;
+				}
+				for(j=1; j < pica->pixels_table[i]; j++)
+				{
+					free_pixels[l++] = i;
+				}
+			}
+		}
+		if (free_num)
+		{
+			PictureFreeColors(
+				dpy, pica->cmap, free_pixels, free_num, 0,
+				pica->no_limit);
+			free(free_pixels);
+		}
+		if (nalloc_pixels != NULL && alloc_pixels != NULL)
+		{
+			*nalloc_pixels = np;
+			*alloc_pixels = save_pixels;
+			if (no_limit != NULL)
+			{
+				*no_limit = pica->no_limit;
+			}
+		}
+		else if (save_pixels)
+		{
+			free(save_pixels);
+		}
+		free(pica->pixels_table);
+	}
+	free(pica);
+	return;
+}
+
 void PictureFreeColors(
 	Display *dpy, Colormap cmap, Pixel *pixels, int n, unsigned long planes,
 	Bool no_limit)
 {
-	if (PStrictColorLimit && Pct != NULL)
+	if (no_limit)
 	{
-		no_limit = 0;
+		if (Pcsi.free_colors_no_limit != NULL)
+		{
+			Pcsi.free_colors_no_limit(
+				dpy, cmap, pixels, n, planes);
+		}
 	}
-	if (Pct != NULL && !no_limit)
+	else
 	{
-		Pixel *p;
-		int i,j,do_free;
-		int m = 0;
-
-		if (!PUseDynamicColors)
+		if (Pcsi.free_colors != NULL)
 		{
-			return;
+			Pcsi.free_colors(dpy, cmap, pixels, n, planes);
 		}
-		p = (Pixel *)safemalloc(n*sizeof(Pixel));
-		for(i= 0; i < n; i++)
-		{
-			do_free = 1;
-			for(j=0; j<PColorLimit; j++)
-			{
-				if (Pct[j].alloc_count &&
-				    Pct[j].alloc_count < 0xffffffff &&
-				    pixels[i] == Pct[j].color.pixel)
-				{
-					(Pct[j].alloc_count)--;
-					if (Pct[j].alloc_count)
-						do_free = 0;
-					break;
-				}
-			}
-			if (do_free)
-			{
-				p[m++] = pixels[i];
-			}
-		}
-		if (m > 0)
-		{
-			XFreeColors(dpy, cmap, p, m, planes);
-		}
-		free(p);
-		return;
-	}
-	if ((Pct == NULL || no_limit) && (Pvisual->class & 1))
-	{
-		XFreeColors(dpy, cmap, pixels, n, planes);
 	}
 	return;
 }
@@ -1921,19 +2188,15 @@ Bool PictureUseBWOnly(void)
 }
 
 int PictureInitColors(
-	int call_type, Bool init_color_limit, char *opt,
+	int call_type, Bool init_color_limit, PictureColorLimitOption *opt,
 	Bool use_my_color_limit, Bool init_dither)
 {
-	if (!use_my_color_limit && opt == NULL)
-	{
-		opt = getenv("FVWM_COLORTABLE_TYPE");
-	}
+	Bool dither_ok = False;
 
 	switch (Pvisual->class)
 	{
-	case TrueColor:
-	case StaticColor:
 	case DirectColor:
+		/* direct colors is more or less broken */
 		decompose_mask(
 			Pvisual->red_mask, &Pcsi.red_shift,
 			&Pcsi.red_prec);
@@ -1943,60 +2206,133 @@ int PictureInitColors(
 		decompose_mask(
 			Pvisual->blue_mask, &Pcsi.blue_shift,
 			&Pcsi.blue_prec);
-		Pcsi.alloc_color_no_limit = alloc_color_static;
+		Pcsi.alloc_color_no_limit = alloc_color_proportion;
+		Pcsi.alloc_color = alloc_color_proportion;
+		Pcsi.alloc_color_dither = alloc_color_proportion_dither;
+		Pcsi.free_colors_no_limit = NULL;
+		Pcsi.free_colors = NULL;
+		PColorLimit = 0;
 		break;
-	case StaticGray:
-		Pcsi.alloc_color_no_limit = alloc_color_static_grey;
-		break;
-	default: /* PseudoColor, GrayScale */
-		Pcsi.alloc_color_no_limit = alloc_color_dynamic_no_limit;
-		break;
-	}
-
-	if (!(Pvisual->class & 1) && opt == NULL)
-	{
-		Bool dither_ok = False;
-
-		/* static classes */
+	case TrueColor:
+		decompose_mask(
+			Pvisual->red_mask, &Pcsi.red_shift,
+			&Pcsi.red_prec);
+		decompose_mask(
+			Pvisual->green_mask, &Pcsi.green_shift,
+			&Pcsi.green_prec);
+		decompose_mask(
+			Pvisual->blue_mask, &Pcsi.blue_shift,
+			&Pcsi.blue_prec);
+		Pcsi.alloc_color_no_limit = alloc_color_proportion;
+		Pcsi.alloc_color = alloc_color_proportion;
+		Pcsi.free_colors_no_limit = NULL;
+		Pcsi.free_colors = NULL;
 		PColorLimit = 0;
-		PUseDynamicColors = 0;
-		if (Pvisual->class != StaticGray)
-		{
-			Pcsi.alloc_color = alloc_color_static;
-		}
-		else
-		{
-			Pcsi.alloc_color = alloc_color_static_grey;
-		}
 		if (init_dither && (Pdepth == 15 || Pdepth == 16))
 		{
 			dither_ok = my_dither_depth_15_16_init();
 		}
 		if (dither_ok)
 		{
-			Pcsi.alloc_color_dither = alloc_color_static_dither;
+			Pcsi.alloc_color_dither = alloc_color_proportion_dither;
 		}
 		else
 		{
 			Pcsi.alloc_color_dither = NULL;
 		}
+		break;
+	case StaticColor:
+		if (0 && Pvisual->red_mask != 0 && Pvisual->green_mask != 0 &&
+		    Pvisual->blue_mask != 0)
+		{
+			decompose_mask(
+				Pvisual->red_mask, &Pcsi.red_shift,
+				&Pcsi.red_prec);
+			decompose_mask(
+				Pvisual->green_mask, &Pcsi.green_shift,
+				&Pcsi.green_prec);
+			decompose_mask(
+				Pvisual->blue_mask, &Pcsi.blue_shift,
+				&Pcsi.blue_prec);
+			Pcsi.alloc_color_no_limit = alloc_color_proportion;
+			Pcsi.alloc_color = alloc_color_proportion;
+			PColorLimit = 0;
+		}
+		else
+		{
+			if (init_color_limit)
+			{
+				Pcsi.alloc_color = alloc_color_in_table;
+				Pcsi.alloc_color_dither =
+					alloc_color_in_table_dither;
+				Pcsi.alloc_color_no_limit = alloc_color_x;
+				init_static_colors_table();
+			}
+			else
+			{
+				Pcsi.alloc_color = alloc_color_x;
+				Pcsi.alloc_color_dither = NULL;
+				Pcsi.alloc_color_no_limit = alloc_color_x;
+			}
+		}
+		Pcsi.free_colors_no_limit = NULL;
+		Pcsi.free_colors = NULL;
+		break;
+	case StaticGray:
+		/* FIXME: we assume that we have a regular grey ramp */
+		if (0)
+		{
+			Pcsi.alloc_color_no_limit = alloc_color_proportion_grey;
+			Pcsi.alloc_color = alloc_color_proportion;
+			PColorLimit = 0;
+		}
+		else
+		{
+			if (init_color_limit)
+			{
+				Pcsi.alloc_color = alloc_color_in_table;
+				Pcsi.alloc_color_dither =
+					alloc_color_in_table_dither;
+				Pcsi.alloc_color_no_limit = alloc_color_x;
+				init_static_colors_table();
+			}
+			else
+			{
+				Pcsi.alloc_color = alloc_color_x;
+				Pcsi.alloc_color_dither = NULL;
+				Pcsi.alloc_color_no_limit = alloc_color_x;
+			}
+		}
+		Pcsi.free_colors_no_limit = NULL;
+		Pcsi.free_colors = NULL;
+		break;
+	case PseudoColor:
+	case GrayScale:
+	default:
+		Pcsi.alloc_color_no_limit = alloc_color_dynamic_no_limit;
+		Pcsi.free_colors_no_limit = free_colors_x;
+		break;
+	}
+
+	if (!(Pvisual->class & 1))
+	{
+		/* static classes */
+		PUseDynamicColors = 0;
 		if (call_type == PICTURE_CALLED_BY_FVWM &&
 		    getenv("FVWM_COLORTABLE_TYPE") != NULL)
 		{
 			putenv("FVWM_COLORTABLE_TYPE=");
 		}
-		return 0;
+		return PColorLimit;
 	}
 
-	/* dynamic classes or testing */
+	/* dynamic classes */
+
 	if (!Pdefault && Pvisual->class == DirectColor)
 	{
 		PColorLimit = 0;
 		PUseDynamicColors = 0;
 		alloc_direct_colors(0, use_my_color_limit);
-		Pcsi.alloc_color = alloc_color_static;
-		Pcsi.alloc_color_no_limit = alloc_color_static;
-		Pcsi.alloc_color_dither = NULL;
 		if (call_type == PICTURE_CALLED_BY_FVWM &&
 		    getenv("FVWM_COLORTABLE_TYPE") != NULL)
 		{
@@ -2011,34 +2347,28 @@ int PictureInitColors(
 		Pcsi.alloc_color = alloc_color_in_table;
 		Pcsi.alloc_color_dither = alloc_color_in_table_dither;
 		PictureAllocColorTable(opt, call_type, use_my_color_limit);
-	}
-	else
-	{
-		if (!(Pvisual->class & 1))
+		if (PUseDynamicColors)
 		{
-			Pcsi.alloc_color = alloc_color_static;
+			Pcsi.free_colors = free_colors_in_table;
 		}
 		else
 		{
-			Pcsi.alloc_color = alloc_color_dynamic_no_limit;
+			Pcsi.free_colors = NULL;
 		}
-		Pcsi.alloc_color_dither = NULL;
 	}
-	if (!(Pvisual->class & 1))
+	else
 	{
-		PUseDynamicColors = 0;
-		if (call_type == PICTURE_CALLED_BY_FVWM)
-		{
-			fprintf(stderr,
-				"[FVWM] WARNING -- You should not use the "
-				"-color-limit option\n");
-		}
+		Pcsi.alloc_color = alloc_color_dynamic_no_limit;
+		Pcsi.free_colors = free_colors_x;
+		Pcsi.alloc_color_dither = NULL;
 	}
 	return PColorLimit;
 }
 
 void PicturePrintColorInfo(int verbose)
 {
+	unsigned long nbr_of_colors = 1 << Pdepth;
+
 	fprintf(stderr, "FVWM info on colors\n");
 	fprintf(stderr, "  Visual ID: 0x%x, Default?: %s, Class: ",
 		(int)(Pvisual->visualid),
@@ -2069,7 +2399,7 @@ void PicturePrintColorInfo(int verbose)
 	}
 	fprintf(stderr, "\n");
 	fprintf(stderr, "  Depth: %i, Number of colors: %lu",
-		Pdepth, (unsigned long)(1 << Pdepth));
+		Pdepth, (unsigned long)nbr_of_colors);
 	if (Pct != NULL)
 	{
 		fprintf(stderr,"\n  Pallet with %i colors", PColorLimit);
@@ -2077,24 +2407,101 @@ void PicturePrintColorInfo(int verbose)
 		{
 			fprintf(stderr,", Number of free colors: %i\n",
 				get_nbr_of_free_colors((1 << Pdepth)));
+			fprintf(stderr,
+				"  Auto Detected: %s, Strict: %s, Allocated: %s,"
+				" Dynamic: %s\n",
+				(Pcsi.pre_allocated_pallet)? "Yes":"No",
+				(PStrictColorLimit)? "Yes":"No",
+				(PAllocTable)? "Yes":"No",
+				(PUseDynamicColors)? "Yes":"No");
 		}
 		else
 		{
-			fprintf(stderr," for testing propose\n");
+			fprintf(stderr," (default colormap)\n");
 		}
-		if (verbose && PColorLimit <= 256)
+		if (PColorLimit <= 256)
 		{
 			int i;
+			int count = 0;
+			int count_alloc = 0;
 
-			fprintf(stderr,"  The fvwm colors table:\n");
+			if (verbose)
+			{
+				fprintf(stderr,"  The fvwm colors table:\n");
+			}
 			for (i = 0; i < PColorLimit; i++)
 			{
+				if (verbose)
+				{
+					fprintf(
+						stderr,
+						"    rgb:%.3i/%.3i/%.3i\t%lu\n",
+						Pct[i].color.red >> 8,
+						Pct[i].color.green >> 8,
+						Pct[i].color.blue >> 8,
+						Pct[i].alloc_count);
+				}
+				if (Pct[i].alloc_count)
+				{
+					count++;
+				}
+			}
+			if ((Pvisual->class & 1) && Pac != NULL)
+			{
+				if (verbose)
+				{
+					fprintf(stderr,"  fvwm colors not in"
+						" the table:\n");
+				}
+				for(i=0; i < nbr_of_colors; i++)
+				{
+					int j = 0;
+					Bool found = False;
+
+					if (!Pac[i].alloc_count)
+						continue;
+					while(j < PColorLimit && !found)
+					{
+						if (i == Pct[j].color.pixel)
+						{
+							found = True;
+						}
+						j++;
+					}
+					if (found)
+						continue;
+					count_alloc++;
+					if (verbose)
+					{
+						fprintf(
+							stderr,
+							"    rgb:"
+							"%.3i/%.3i/%.3i\t%lu\n",
+							Pac[i].color.red >> 8,
+							Pac[i].color.green >> 8,
+							Pac[i].color.blue >> 8,
+							Pac[i].alloc_count);
+					}
+				}
+				if (verbose && count_alloc == 0)
+				{
+					if (verbose)
+					{
+						fprintf(stderr,"    None\n");
+					}
+				}
+			}
+			if (Pvisual->class & 1)
+			{
+				fprintf(stderr,
+					"  Number of colours used by fvwm:\n");
+				fprintf(stderr,
+					"    In the table: %i\n", count);
 				fprintf(
-					stderr,"    rgb:%.3i/%.3i/%.3i\t%lu\n",
-					Pct[i].color.red >> 8,
-					Pct[i].color.green >> 8,
-					Pct[i].color.blue >> 8,
-					Pct[i].alloc_count);
+					stderr, "    Out of the table: %i\n",
+					count_alloc);
+				fprintf(stderr,
+					"    Total: %i\n", count_alloc+count);
 			}
 		}
 	}
@@ -2128,9 +2535,9 @@ void PicturePrintColorInfo(int verbose)
 		}
 	}
 
-	if (Pdepth <= 8 && verbose >= 2 && !Pdefault)
+	if (Pdepth <= 8 && verbose >= 2)
 	{
-		fprintf(stderr,"\n  Default Colormap (not used by fvwm):\n");
+		fprintf(stderr,"\n  Default Colormap:\n");
 		print_colormap(DefaultColormap(Pdpy,DefaultScreen(Pdpy)));
 	}
 }
