@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -97,7 +98,7 @@ void setPath(char **p_path, const char *newpath, int free_old_path)
 }
 
 
-/****************************************************************************
+/*
  *
  * Find the specified file somewhere along the given path.
  *
@@ -105,7 +106,7 @@ void setPath(char **p_path, const char *newpath, int free_old_path)
  * do something with it.  By then, the file might not be accessible.
  * Oh well.
  *
- ****************************************************************************/
+ */
 #include <stdio.h>
 char *searchPath(
 	const char *pathlist, const char *filename, const char *suffix,
@@ -239,3 +240,94 @@ Bool isFileStampChanged(const FileStamp *stamp, const char *name)
 {
 	return *stamp != getFileStamp(name);
 }
+
+#ifdef HAVE_SAFTY_MKSTEMP
+int fvwm_mkstemp (char *TEMPLATE)
+{
+	return mkstemp(TEMPLATE);
+}
+#else
+
+/* This function is an adaptation of the mkstemp() function included
+ * in the Gnu C Library, version 2.2.2. The Gnu C library, in turn,
+ * adapted the function from OpenBSD.
+ * Michael Han <mikehan@mikehan.com> */
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <errno.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <unistd.h>
+#include <sys/time.h>
+
+#define __set_errno(val) errno = (val)
+
+/* These are the characters used in temporary filenames.  */
+static const char letters[] =
+"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
+
+/* Generate a unique temporary file name from TEMPLATE.
+   The last six characters of TEMPLATE must be "XXXXXX";
+   they are replaced with a string that makes the filename unique.
+   Then open the file and return a fd. */
+
+int fvwm_mkstemp (char *template)
+{
+	int len;
+	char *XXXXXX;
+	static unsigned long value;
+	struct timeval tv;
+	int count, fd = -1;
+	int save_errno = errno;
+
+	len = strlen (template);
+	if (len < 6 || strcmp (&template[len - 6], "XXXXXX"))
+	{
+		__set_errno (EINVAL);
+		return -1;
+	}
+
+	/* This is where the Xs start.  */
+	XXXXXX = &template[len - 6];
+
+	/* Get some more or less random data.  */
+	gettimeofday (&tv, NULL);
+	value = ((unsigned long) tv.tv_usec << 16) ^ tv.tv_sec ^ getpid ();
+
+	for (count = 0; count < TMP_MAX; value = 7777, count)
+	{
+		unsigned long v = value;
+
+		/* Fill in the random bits.  */
+		XXXXXX[0] = letters[v % 62];
+		v /= 62;
+		XXXXXX[1] = letters[v % 62];
+		v /= 62;
+		XXXXXX[2] = letters[v % 62];
+		v /= 62;
+		XXXXXX[3] = letters[v % 62];
+		v /= 62;
+		XXXXXX[4] = letters[v % 62];
+		v /= 62;
+		XXXXXX[5] = letters[v % 62];
+
+		fd = open (template, O_RDWR | O_CREAT | O_EXCL, 0600);
+
+		if (fd >= 0)
+		{
+			__set_errno (save_errno);
+			return fd;
+		}
+		else if (errno != EEXIST)
+		{
+			return -1;
+		}
+	}
+
+	/* We got out of the loop because we ran out of combinations to try.  */
+	__set_errno (EEXIST);
+	return -1;
+}
+#endif /* HAVE_SAFTY_MKSTEMP */
