@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -24,7 +25,7 @@
 
 #include "wild.h"
 
-/*****************************************************************************
+/*
  *      Does `string' match `pattern'? '*' in pattern matches any sub-string
  *      (including the null string) '?' matches any single char. For use
  *      by filenameforall. Note that '*' matches across directory boundaries
@@ -32,63 +33,66 @@
  *      This code donated by  Paul Hudson <paulh@harlequin.co.uk>
  *      It is public domain, no strings attached. No guarantees either.
  *
- *****************************************************************************/
+ */
 int matchWildcards(char *pattern, char *string)
 {
-  if(string == NULL)
-    {
-      if(pattern == NULL)
-	return TRUE;
-      else if(strcmp(pattern,"*")==0)
-	return TRUE;
-      else
-	return FALSE;
-    }
-  if(pattern == NULL)
-    return TRUE;
+	if(string == NULL)
+	{
+		if(pattern == NULL)
+			return TRUE;
+		else if(strcmp(pattern,"*")==0)
+			return TRUE;
+		else
+			return FALSE;
+	}
+	if(pattern == NULL)
+		return TRUE;
 
-  while (*string && *pattern)
-    {
-      if (*pattern == '?')
+	while (*string && *pattern)
 	{
-	  /* match any character */
-	  pattern += 1;
-	  string += 1;
-	}
-      else if (*pattern == '*')
-	{
-	  /* see if the rest of the pattern matches any trailing substring
-	     of the string. */
-	  pattern += 1;
-	  if (*pattern == 0)
-	    {
-	      return TRUE; /* trailing * must match rest */
-	    }
-	  while (*string)
-	    {
-	      if (matchWildcards(pattern,string))
+		if (*pattern == '?')
 		{
-		  return TRUE;
+			/* match any character */
+			pattern += 1;
+			string += 1;
+		}
+		else if (*pattern == '*')
+		{
+			/* see if the rest of the pattern matches any trailing
+			 * substring of the string. */
+			pattern += 1;
+			if (*pattern == 0)
+			{
+				return TRUE; /* trailing * must match rest */
+			}
+			while (*string)
+			{
+				if (matchWildcards(pattern,string))
+				{
+					return TRUE;
+				}
+				string++;
+			}
+			return FALSE;
+		}
+		else
+		{
+			if (*pattern == '\\')
+			{
+				/* has strange, but harmless effects if the
+				 * last character is a '\\' */
+				pattern ++;
+			}
+			if  (*pattern++ != *string++)
+			{
+				return FALSE;
+			}
 		}
-	      string++;
-	    }
-	  return FALSE;
 	}
-      else
-	{
-	  if (*pattern == '\\')
-	    pattern ++;    /* has strange, but harmless effects if the last
-			      character is a '\\' */
-	  if  (*pattern++ != *string++)
-	    {
-	      return FALSE;
-	    }
-	}
-    }
-  if((*pattern == 0)&&(*string == 0))
-    return TRUE;
-  if((*string == 0)&&(strcmp(pattern,"*")==0))
-    return TRUE;
-  return FALSE;
+	if((*pattern == 0)&&(*string == 0))
+		return TRUE;
+	if((*string == 0)&&(strcmp(pattern,"*")==0))
+		return TRUE;
+	return FALSE;
 }
 
