@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This module, and the entire FvwmAuto program, and the concept for
  * interfacing this module to the Window Manager, are all original work
  * by Robert Nation
@@ -67,37 +68,39 @@
 
 static RETSIGTYPE TerminateHandler(int signo);
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *  Termination procedure : *not* a signal handler
  *
- ***********************************************************************/
-void DeadPipe(int nonsense)
+ */
+RETSIGTYPE DeadPipe(int nonsense)
 {
 	(void)nonsense;
 	myfprintf((stderr,"Leaving via DeadPipe\n"));
 	exit(0);
+	SIGNAL_RETURN;
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *  Signal handler that tells the module to quit
  *
- ***********************************************************************/
+ */
 static RETSIGTYPE
 TerminateHandler(int signo)
 {
 	fvwmSetTerminate(signo);
+	SIGNAL_RETURN;
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      main - start of module
  *
- ***********************************************************************/
+ */
 int
 main(int argc, char **argv)
 {
