@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /*
  * FvwmButtons, copyright 1996, Jarl Totland
  *
@@ -12,35 +13,22 @@
  *
  */
 
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
- */
-
 /* --------------------------- button information -------------------------- */
 
-void buttonInfo(button_info*,int *x,int *y,int *padx,int *pady,int *frame);
+void buttonInfo(
+	const button_info*, int *x, int *y, int *padx, int *pady, int *frame);
 void GetInternalSize(button_info*,int*,int*,int*,int*);
 #define buttonFrame(b) abs(buttonFrameSigned(b))
 int buttonFrameSigned(button_info*);
 int buttonXPad(button_info*);
 int buttonYPad(button_info*);
 FlocaleFont *buttonFont(button_info*);
-Pixel buttonFore(button_info*);
-Pixel buttonBack(button_info*);
+Pixel buttonFore(const button_info *);
+Pixel buttonBack(const button_info *);
 Pixel buttonHilite(button_info*);
 Pixel buttonShadow(button_info*);
 int buttonColorset(button_info *b);
+int buttonBackgroundButton(button_info *b, button_info **r_b);
 byte buttonSwallow(button_info*);
 byte buttonJustify(button_info*);
 #define buttonNum(b) ((b)->n)
@@ -68,11 +56,11 @@ button_info *select_button(button_info*,int,int);
 
 /* --------------------------- button geometry ----------------------------- */
 
-int buttonXPos(button_info *b, int i);
-int buttonYPos(button_info *b, int i);
-int buttonWidth(button_info *b);
-int buttonHeight(button_info *b);
-void get_button_root_geometry(rectangle *r, button_info *b);
+int buttonXPos(const button_info *b, int i);
+int buttonYPos(const button_info *b, int i);
+int buttonWidth(const button_info *b);
+int buttonHeight(const button_info *b);
+void get_button_root_geometry(rectangle *r, const button_info *b);
 
 /* --------------------------- swallowing ---------------------------------- */
 
