@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /*
  * FvwmButtons, copyright 1996, Jarl Totland
  *
@@ -27,6 +28,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "config.h"
+
 #include <unistd.h>
 #include <ctype.h>
 #include <stdlib.h>
