@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /*
   Fvwm command input interface.
 
@@ -22,6 +23,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "config.h"
+
 #include "FvwmConsole.h"
 
 char *MyName;
@@ -32,7 +35,7 @@ char Name[80]; /* name of this program in executable format */
 char *S_name;  /* socket name */
 
 void server( void );
-void DeadPipe( int );
+RETSIGTYPE DeadPipe( int );
 void CloseSocket();
 void ErrMsg( char *msg );
 void SigHandler( int );
@@ -135,24 +138,26 @@ int main(int argc, char *argv[])
   return (0);
 }
 
-/***********************************************************************
+/*
  *      signal handler
- ***********************************************************************/
-void DeadPipe( int dummy )
+ */
+RETSIGTYPE DeadPipe( int dummy )
 {
   CloseSocket();
   exit(0);
+  SIGNAL_RETURN;
 }
 
-void SigHandler(int dummy)
+RETSIGTYPE SigHandler(int dummy)
 {
   CloseSocket();
   exit(1);
+  SIGNAL_RETURN;
 }
 
-/*********************************************************/
-/* close sockets and spawned process                     */
-/*********************************************************/
+/*
+ * close sockets and spawned process
+ */
 void CloseSocket()
 {
   send(Ns, C_CLOSE, strlen(C_CLOSE), 0);
@@ -161,9 +166,9 @@ void CloseSocket()
 
 }
 
-/*********************************************************/
-/* setup server and communicate with fvwm and the client */
-/*********************************************************/
+/*
+ * setup server and communicate with fvwm and the client
+ */
 void server ( void )
 {
   struct sockaddr_un sas, csas;
@@ -230,7 +235,7 @@ void server ( void )
   send(Ns, C_END, strlen(C_END), 0);
   strcpy( ver, MyName);
   strcat( ver, " version " );
-  strcat( ver, VERSION);
+  strcat( ver, VERSION VERSIONINFO);
   strcat( ver, "\n" );
   send(Ns, ver, strlen(ver), 0 );
 
@@ -258,6 +263,7 @@ void server ( void )
       }
 
       if (FD_ISSET(Ns, &fdset)){
+	  int len;
 	  if( recv( Ns, buf, MAX_COMMAND_SIZE,0 ) == 0 ) {
 	    /* client is terminated */
 	    close(Ns);
@@ -266,14 +272,19 @@ void server ( void )
 	  }
 
 	  /* process the own unique commands */
+	  len = strlen(buf);
+	  if (len > 0 && buf[len - 1] == '\n')
+	  {
+	    buf[len - 1] = '\0';
+	  }
 	  SendText(Fd,buf,0); /* send command */
       }
   }
 }
 
-/******************************************/
-/* print error message on stderr and exit */
-/******************************************/
+/*
+ * print error message on stderr and exit
+ */
 void ErrMsg( char *msg )
 {
   fprintf( stderr, "%s server error in %s, errno %d\n", Name, msg, errno );
