@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -5,33 +6,34 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "FvwmConsole.h"
 
-int  s;	   /* socket handle */
+int  s;    /* socket handle */
 FILE *sp;
 char *name;  /* name of this program at executing time */
 char *getline();
 
 
-/******************************************/
-/*  close socket and exit */
-/******************************************/
+/*
+ *  close socket and exit
+ */
 void sclose (int foo) {
   fclose(sp);
   exit(0);
+  SIGNAL_RETURN;
 }
 
-/************************************/
-/* print error message on stderr */
-/************************************/
+/*
+ * print error message on stderr
+ */
 void ErrMsg( char *msg ) {
   fprintf( stderr, "%s error in %s\n", name , msg );
   fclose(sp);
@@ -39,10 +41,10 @@ void ErrMsg( char *msg ) {
 }
 
 
-/*******************************************************/
-/* setup socket.				       */
-/* send command to and receive message from the server */
-/*******************************************************/
+/*
+ * setup socket.
+ * send command to and receive message from the server
+ */
 int main ( int argc, char *argv[]) {
   char *cmd;
   char data[MAX_MESSAGE_SIZE];
