@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -22,6 +23,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include "config.h"
 
 #ifdef HAVE_SYS_BSDTYPES_H
 #include <sys/bsdtypes.h> /* Saul */
@@ -364,7 +366,7 @@ void parseFvwmMessage(char *msg)
 }
 
 
-/************************************************************************
+/*
  * TerminateHandler - signal handler to make FvwmIconBox exit cleanly
  */
 static RETSIGTYPE
@@ -376,6 +378,7 @@ TerminateHandler(int sig)
    * BEFORE we call it ...
    */
   fvwmSetTerminate(sig);
+  SIGNAL_RETURN;
 }
 
 
@@ -732,7 +735,7 @@ static void change_colorset(int colorset)
 
 
 
-/***************************************************************************
+/*
  *
  * myXNextEvent - waits for the next event, which is either an XEvent,
  *                  or an fvwm event.
@@ -745,7 +748,7 @@ static void change_colorset(int colorset)
  * Note that for fvwm packet type M_CONFIG(colorset), it updates the
  *  colorset
  * Borrowed from FvwmPager
- ****************************************************************************/
+ */
 int myXNextEvent(XEvent *event, char *fvwmMessage)
 {
   fd_set in_fdset;
