@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* FvwmForm is original work of Thomas Zuwei Feng.
  *
  * Copyright Feb 1995, Thomas Zuwei Feng.  No guarantees or warantees are
@@ -2508,6 +2509,7 @@ static RETSIGTYPE
 TerminateHandler(int sig)
 {
   fvwmSetTerminate(sig);
+  SIGNAL_RETURN;
 }
 
 /* signal-handler to make the timer work */
@@ -2563,6 +2565,8 @@ TimerHandler(int sig)
     RedrawTimeout(timer);
     alarm(1);
   }
+
+  SIGNAL_RETURN;
 }
 
 
@@ -2701,14 +2705,15 @@ int main (int argc, char **argv)
 }
 
 
-void DeadPipe(int nonsense)
+RETSIGTYPE DeadPipe(int nonsense)
 {
   exit(0);
+  SIGNAL_RETURN;
 }
 
-/************************************************************************
+/*
   X Error Handler
-************************************************************************/
+*/
 static int
 ErrorHandler(Display *dpy, XErrorEvent *event)
 {
