@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* FvwmIconBox Module --- Copyright 1994, 1995 Nobutaka Suzuki.
  *
  * No guarantees or warantees or anything are provided or implied in
@@ -89,6 +90,9 @@ int Iconcolorset = -1;
 int IconHicolorset = -1;
 Bool UseSkipList = False;
 Bool Swallowed = False;
+Window SwallowerWin = False;
+Bool Shaded = False;
+Bool SwallowerShaded = False;
 
 /* same strings as in misc.c */
 char NoClass[] = "NoClass";
@@ -189,7 +193,6 @@ int sortby = UNSORT;
 
 char* AnimCommand = NULL;
 
-int save_color_limit = 0;                   /* color limit from config */
 static Bool have_double_click = False;
 static Bool is_dead_pipe = False;
 
@@ -201,11 +204,11 @@ static void change_colorset(int color);
 Bool do_allow_bad_access = False;
 Bool was_bad_access = False;
 
-/************************************************************************
+/*
   Main
   Based on main() from GoodStuff:
 	Copyright 1993, Robert Nation.
-************************************************************************/
+*/
 int main(int argc, char **argv)
 {
   char *display_name = NULL;
@@ -335,11 +338,11 @@ int main(int argc, char **argv)
 
 
 
-/************************************************************************
+/*
   Loop
   Based on Loop() from GoodStuff:
       Copyright 1993, Robert Nation.
-************************************************************************/
+*/
 void Loop(void)
 {
   Window root;
@@ -704,11 +707,11 @@ struct icon_info *Search(Window w)
   return NULL;
 }
 
-/************************************************************************
+/*
  *
  * Draw the window
  *
- ***********************************************************************/
+ */
 void RedrawWindow(XEvent *evp)
 {
   XEvent dummy;
@@ -1116,6 +1119,18 @@ void animate(struct icon_info *item, unsigned long *body)
     int abs_x, abs_y;
     Window junkw;
 
+    /* do not animate if shaded */
+    if (Swallowed)
+    {
+	    if (SwallowerShaded)
+	    {
+		    return;
+	    }
+    }
+    else if (Shaded)
+    {
+	    return;
+    }
     /* check to see if the centre of the icon is displayed in the iconbox */
     XTranslateCoordinates(dpy, icon_win, main_win, item->x + (item->icon_w/2),
 			  item->y + (item->icon_h/2), &abs_x, &abs_y, &junkw);
@@ -1141,11 +1156,11 @@ void animate(struct icon_info *item, unsigned long *body)
   }
 }
 
-/***********************************************************************
+/*
  * RedrawHScrollbar
  *      Based on part of Loop() of GrabWindow.c in FvwmScroll:
  *              Copyright 1994, Robert Nation.
- ***********************************************************************/
+ */
 void RedrawHScrollbar(void)
 {
   int x,width;
@@ -1157,11 +1172,11 @@ void RedrawHScrollbar(void)
 		   ReliefGC, ShadowGC, 2);
 }
 
-/***********************************************************************
+/*
  * RedrawVScrollbar
  *      Based on part of Loop() of GrabWindow.c in FvwmScroll:
  *              Copyright 1994, Robert Nation.
- ***********************************************************************/
+ */
 void RedrawVScrollbar(void)
 {
   int y, height;
@@ -1282,11 +1297,11 @@ void RedrawBottomButton(GC rgc, GC sgc)
   XDrawSegments(dpy, b_button, sgc, seg, i);
 }
 
-/************************************************************************
+/*
  * CreateWindow --Sizes and creates the window
  *      Based on CreateWindow() from GoodStuff:
  *              Copyright 1993, Robert Nation.
- ***********************************************************************/
+ */
 void CreateWindow(void)
 {
   XGCValues gcv;
@@ -1835,7 +1850,7 @@ void Prev(void)
   }
 }
 
-/************************************************************************
+/*
  * TerminateHandler - signal handler to make FvwmIconBox exit cleanly
  */
 static RETSIGTYPE
@@ -1847,19 +1862,21 @@ TerminateHandler(int sig)
    * BEFORE we call it ...
    */
   fvwmSetTerminate(sig);
+  SIGNAL_RETURN;
 }
 
 
-/************************************************************************
+/*
  * DeadPipe --Dead pipe handler
  *      Based on DeadPipe() from GoodStuff:
  *              Copyright 1993, Robert Nation.
- ***********************************************************************/
+ */
 void
 DeadPipe(int nonsense)
 {
   is_dead_pipe = True;
   exit(0);
+  SIGNAL_RETURN;
 }
 
 static void
@@ -1938,11 +1955,11 @@ CleanUp(void)
 }
 
 
-/************************************************************************
+/*
  * ParseOptions
  *      Based on ParseConfig() from FvwmWinList:
  *              Copyright 1994, Mike Finger.
- ***********************************************************************/
+ */
 void ParseOptions(void)
 {
   char *tline= NULL,*tmp;
@@ -2226,10 +2243,6 @@ void ParseOptions(void)
       {
 	ClickTime = atoi(&tline[9]);
       }
-      else if (strncasecmp(tline,"ColorLimit",10)==0)
-      {
-	save_color_limit = atoi(&tline[10]);
-      }
     }
     GetConfigLine(fd,&tline);
   }
@@ -2381,13 +2394,13 @@ void parsemouse(char *tline)
   MouseActions = f;
 }
 
-/***********************************************************************
+/*
   parsekey
 	Based on part of AddFunckey() of configure.c in Fvwm.
 	Copyright 1988, Evans and Sutherland Computer Corporation,
 	Copyright 1989, Massachusetts Institute of Technology,
 	Copyright 1993, Robert Nation.
- ***********************************************************************/
+*/
 void parsekey(char *tline)
 {
   struct keyfunc *k;
@@ -2448,11 +2461,11 @@ void parsekey(char *tline)
       }
 }
 
-/***********************************************************************
+/*
  * change_window_name
  *      Original work from GoodStuff:
  *              Copyright 1993, Robert Nation.
- ***********************************************************************/
+ */
 void change_window_name(char *str)
 {
   XTextProperty name;
@@ -2467,11 +2480,11 @@ void change_window_name(char *str)
   XFree(name.value);
 }
 
-/***********************************************************************
+/*
  * My_XNextEvent
  *      Original work from GoodStuff:
  *              Copyright 1993, Robert Nation.
- ***********************************************************************/
+ */
 int My_XNextEvent(Display *dpy, XEvent *event)
 {
   fd_set in_fdset;
@@ -2516,11 +2529,11 @@ int My_XNextEvent(Display *dpy, XEvent *event)
   return 0;
 }
 
-/**************************************************************************
+/*
  * process_message
  *      Based on ProcessMassage() from FvwmWinList:
  *              Copyright 1994, Mike Finger.
- *************************************************************************/
+ */
 int diffx, diffy;
 void process_message(unsigned long type, unsigned long *body)
 {
@@ -2532,6 +2545,14 @@ void process_message(unsigned long type, unsigned long *body)
   switch(type)
   {
   case M_CONFIGURE_WINDOW:
+    if (cfgpacket->w == main_win)
+    {
+	    Shaded = IS_SHADED(cfgpacket);
+    }
+    if (SwallowerWin && cfgpacket->w == SwallowerWin)
+    {
+	    SwallowerShaded = IS_SHADED(cfgpacket);
+    }
     if (ready)
     {
       tmp = Head;
@@ -2816,7 +2837,23 @@ void process_message(unsigned long type, unsigned long *body)
     }
     else if  (body[0] == MX_PROPERTY_CHANGE_SWALLOW && body[2] == icon_win)
     {
-      Swallowed = body[1];
+	    char *str;
+	    
+	    Swallowed = body[1];
+	    str = (char *)&body[3];
+
+	    if (Swallowed && str)
+	    {
+		    unsigned long u;
+		    if (sscanf(str,"%lu",&u) == 1)
+		    {
+			    SwallowerWin = (Window)u;
+		    }
+		    else
+		    {
+			    SwallowerWin = 0;
+		    }
+	    }
     }
     break;
   default:
@@ -2882,11 +2919,11 @@ int window_cond(struct icon_info *item)
   return 0;
 }
 
-/************************************************************************
+/*
  * AddItem
  *      Skeleton based on AddItem() from FvwmWinList:
  *              Copyright 1994, Mike Finger.
- ***********************************************************************/
+ */
 /*Bool AddItem(unsigned long id, long desk, unsigned long flags) */
 Bool AddItem(ConfigWinPacket *cfgpacket)
 {
@@ -2939,11 +2976,11 @@ Bool AddItem(ConfigWinPacket *cfgpacket)
   return False;
 }
 
-/************************************************************************
+/*
  * Deletetem
  *      Skeleton based on DeleteItem() from FvwmWinList:
  *              Copyright 1994, Mike Finger.
- ***********************************************************************/
+ */
 Bool DeleteItem(unsigned long id)
 {
   struct icon_info *tmp = Head;
@@ -2979,11 +3016,11 @@ Bool DeleteItem(unsigned long id)
   return False;
 }
 
-/************************************************************************
+/*
  * UpdateItem
  *      Skeleton based on UpdateItem() from FvwmWinList:
  *              Copyright 1994, Mike Finger.
- ***********************************************************************/
+ */
 struct icon_info *UpdateItem(unsigned long type, unsigned long id, char *item)
 {
   struct icon_info *tmp;
@@ -3260,10 +3297,10 @@ void freeitem(struct icon_info *item, int d)
 }
 
 
-/************************************************************************
+/*
  * CheckActionType
  *   Based on functions.c from Fvwm:
- ***********************************************************************/
+ */
 static int CheckActionType(
   int x, int y, XEvent *d, Bool may_time_out, Bool is_button_pressed)
 {
@@ -3328,13 +3365,13 @@ static int CheckActionType(
 }
 
 
-/************************************************************************
+/*
  * ExecuteAction
 *       Based on part of ComplexFunction() of functions.c from fvwm:
 	Copyright 1988, Evans and Sutherland Computer Corporation,
 	Copyright 1989, Massachusetts Institute of Technology,
 	Copyright 1993, Robert Nation.
- ***********************************************************************/
+*/
 void ExecuteAction(int x, int y, struct icon_info *item)
 {
   int type = NO_CLICK;
@@ -3401,13 +3438,13 @@ void ExecuteKey(XEvent event)
   }
 }
 
-/***********************************************************************
+/*
  LookInList
 	Based on part of LookInList() of add_window.c from fvwm:
 	Copyright 1988, Evans and Sutherland Computer Corporation,
 	Copyright 1989, Massachusetts Institute of Technology,
 	Copyright 1993, Robert Nation.
- ***********************************************************************/
+*/
 int LookInList(struct icon_info *item)
 {
   int isdefault=1;
@@ -3482,13 +3519,13 @@ int LookInList(struct icon_info *item)
   return 1;
 }
 
-/***********************************************************************
+/*
  strcpy
 	Based on stripcpy2() of configure.c from Fvwm:
 	Copyright 1988, Evans and Sutherland Computer Corporation,
 	Copyright 1989, Massachusetts Institute of Technology,
 	Copyright 1993, Robert Nation.
- ***********************************************************************/
+*/
 char *stripcpy2(char *source)
 {
   char *ptr;
@@ -3510,9 +3547,9 @@ char *stripcpy2(char *source)
   return ptr;
 }
 
-/***********************************************************************
+/*
  Error handler
- ***********************************************************************/
+*/
 static int
 myErrorHandler(Display *dpy, XErrorEvent *event)
 {
