@@ -1,23 +1,9 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
-/*************************************************************************
+/* -*-c-*- */
+/*
  *
  * Subroutine Prototypes
  *
- *************************************************************************/
+ */
 #include "libs/fvwmlib.h"
 #include <libs/vpacket.h>
 #include "libs/Flocale.h"
@@ -36,7 +22,7 @@ extern void   Loop(void);
 extern void   ParseOptions(void);
 extern char   *safemalloc(int length);
 extern int    My_XNextEvent(Display *dpy, XEvent *event);
-extern void   DeadPipe(int nonsense);
+extern RETSIGTYPE DeadPipe(int nonsense);
 extern void   CreateIconWindow(struct icon_info *item);
 extern void   DrawIconWindow(struct icon_info *item);
 extern void   GetIconFromFile(struct icon_info *item);
