@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -13,6 +14,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "config.h"
+
 #include <limits.h>
 #include "FvwmIconMan.h"
 #include "xmanager.h"
@@ -80,6 +83,7 @@ static void init_win_manager(int id)
 	globals.managers[id].we_are_drawing = 1;
 	globals.managers[id].showonlyiconic = 0;
 	globals.managers[id].showtransient = 0;
+	globals.managers[id].relief_thickness = 2;
 }
 
 void print_managers(void)
