@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -59,9 +60,9 @@ typedef struct {
 static void print_button_info(Button *b);
 static void insert_windows_button(WinData *win);
 
-/***************************************************************************/
-/* Utility leaf functions                                                  */
-/***************************************************************************/
+/*
+ * Utility leaf functions
+ */
 
 static int selected_button_in_man(WinManager *man)
 {
@@ -523,9 +524,9 @@ Button *xy_to_button(WinManager *man, int x, int y)
   return NULL;
 }
 
-/***************************************************************************/
-/* Routines which change dirtyable state                                   */
-/***************************************************************************/
+/*
+ * Routines which change dirtyable state
+ */
 
 static void set_button_geometry(WinManager *man, Button *box)
 {
@@ -690,45 +691,105 @@ void set_win_picture(WinData *win, Pixmap picture, Pixmap mask, Pixmap alpha,
 
 void set_win_iconified(WinData *win, int iconified)
 {
-  /* This change has become necessary because with colorsets we don't know
-   * the background colour of the button (gradient background). Thus the button
-   * has to be redrawn completely, we can not just draw the square in the
-   * background colour. */
-   char string[256];
+	/* This change has become necessary because with colorsets we don't
+	 * know the background colour of the button (gradient background).
+	 * Thus the button has to be redrawn completely, we can not just draw
+	 * the square in the background colour. */
+	char string[256];
+	WinData *man_data = NULL;
+	Bool do_animate = True;
 
-  if (win->button != NULL && (win->iconified != iconified) ) {
-    /* we check the win->button width and height because they will only
-     * be == zero on init, and if we didn't check we would get animations of
-     * all iconified windows to the far left of whereever thae manager would
-     * eventually be. */
-    if (win->manager->AnimCommand && (win->manager->AnimCommand[0] != 0)
-	&& IS_ICON_SUPPRESSED(win) && (win->button->w != 0)
-	&& (win->button->h !=0) )
-    {
-      int abs_x, abs_y;
-      Window junkw;
+	if (win->button != NULL && (win->iconified != iconified) )
+	{
+		if (win->manager->flags.is_shaded)
+		{
+			man_data = id_to_win(win->manager->theWindow);
+			if (!man_data->geometry_set)
+			{
+				do_animate = False;
+			}
+		}
+		else if (win->manager->swallowed)
+		{
+			if (win->manager->swallower_win &&
+			    (man_data =
+			     id_to_win(win->manager->swallower_win)) &&
+			    man_data->geometry_set)
+			{
+				/* ok */
+				if (!IS_SHADED(man_data))
+				{
+					/* animate as usual */
+					man_data = NULL;
+				}
+			}
+			else
+			{
+				do_animate = False;
+			}
+		}
+		/* we check the win->button width and height because they
+		 * will only be == zero on init, and if we didn't check we
+		 * would get animations of all iconified windows to the far
+		 * left of whereever thae manager would eventually be. */
+		if (do_animate && win->manager->AnimCommand &&
+		    (win->manager->AnimCommand[0] != 0)
+		    && IS_ICON_SUPPRESSED(win) && (win->button->w != 0)
+		    && (win->button->h !=0))
+		{
+			int abs_x, abs_y, w, h;
+			Window junkw;
 
-      XTranslateCoordinates(theDisplay, win->manager->theWindow, theRoot,
-			    win->button->x, win->button->y, &abs_x, &abs_y,
-			    &junkw);
-      if (iconified)
-      {
-	sprintf(string, "%s %d %d %d %d %d %d %d %d",
-		win->manager->AnimCommand,
-		(int)win->x, (int)win->y, (int)win->width, (int)win->height,
-		abs_x, abs_y, win->button->w, win->button->h);
-      } else {
-	sprintf(string, "%s %d %d %d %d %d %d %d %d",
-		win->manager->AnimCommand,
-		abs_x, abs_y, win->button->w, win->button->h,
-		(int)win->x, (int)win->y, (int)win->width, (int)win->height);
-      }
-      SendText(fvwm_fd, string, 0);
-
-    }
-    win->button->drawn_state.dirty_flags |= ICON_STATE_CHANGED;
-  }
-  win->iconified = iconified;
+			XTranslateCoordinates(
+				theDisplay, win->manager->theWindow,
+				theRoot, win->button->x, win->button->y,
+				&abs_x, &abs_y, &junkw);
+			w = win->button->w;
+			h = win->button->h;
+			if (man_data)
+			{
+				if (w > man_data->real_g.width)
+				{
+					w = 1;
+				}
+				if (h > man_data->real_g.height)
+				{
+					h = 1;
+				}
+				if (abs_x < man_data->real_g.x ||
+				    abs_x > man_data->real_g.x +
+				    man_data->real_g.width)
+				{
+					abs_x = man_data->real_g.x;
+				}
+				if (abs_y < man_data->real_g.y ||
+				    abs_y > man_data->real_g.y +
+				    man_data->real_g.height)
+				{
+					abs_y = man_data->real_g.y;
+				}
+			}
+			if (iconified)
+			{
+				sprintf(string, "%s %d %d %d %d %d %d %d %d",
+					win->manager->AnimCommand,
+					(int)win->x, (int)win->y,
+					(int)win->width, (int)win->height,
+					abs_x, abs_y, w, h);
+			}
+			else
+			{
+				sprintf(string, "%s %d %d %d %d %d %d %d %d",
+					win->manager->AnimCommand,
+					abs_x, abs_y, w, h,
+					(int)win->x, (int)win->y,
+					(int)win->width, (int)win->height);
+			}
+			SendText(fvwm_fd, string, 0);
+		}
+		win->button->drawn_state.dirty_flags |= ICON_STATE_CHANGED;
+	}
+	win->iconified = iconified;
 }
 
 void set_win_state(WinData *win, int state)
@@ -1053,9 +1114,9 @@ void set_manager_window_mapping(WinManager *man, int flag)
   }
 }
 
-/***************************************************************************/
-/* Major exported functions                                                */
-/***************************************************************************/
+/*
+ * Major exported functions
+ */
 
 void init_boxes(void)
 {
@@ -1275,13 +1336,13 @@ static void draw_button_background(
 static void draw_3d_icon(WinManager *man, int box, ButtonGeometry *g,
 			  int iconified, Contexts contextId)
 {
-  if (iconified == 0)
+  if ((iconified == 0) || (man->relief_thickness == 0))
     return;
   else
     RelieveRectangle(theDisplay, man->theWindow, g->icon_x, g->icon_y,
 		      g->icon_w - 1, g->icon_h - 1,
 		      man->reliefContext[contextId],
-		      man->shadowContext[contextId], 2);
+		      man->shadowContext[contextId], man->relief_thickness);
 }
 
 
@@ -1476,19 +1537,36 @@ static void draw_relief(WinManager *man, int button_state, ButtonGeometry *g,
 			 GC context1, GC context2)
 {
   int state;
-  state = man->buttonState[button_state];
+  int relief;
 
-  if (state == BUTTON_FLAT)
+  state = man->buttonState[button_state];
+  relief = man->relief_thickness;
+
+  /* Make sure that the relief isn't too large for the button... */
+  if ((abs(relief) > (man->geometry.boxheight / 2)) ||
+      (abs(relief) > (man->geometry.boxwidth / 2))) {
+      relief = min(man->geometry.boxheight/2, man->geometry.boxwidth/2);
+      if (man->relief_thickness < 0)
+        relief *= -1;
+      fprintf(stderr, "%s: Requested relief (%d) too large (for %dx%d box); capped to %d.\n",
+	      MyName, man->relief_thickness, man->geometry.boxwidth, man->geometry.boxheight, relief);
+      man->relief_thickness = relief;
+  }
+
+  if (state == BUTTON_FLAT || relief == 0)
     return;
   if (state == BUTTON_EDGEUP || state == BUTTON_EDGEDOWN) {
     RelieveRectangle(theDisplay, man->theWindow, g->button_x, g->button_y,
-		      g->button_w - 1, g->button_h - 1, context1, context2, 2);
+		      g->button_w - 1, g->button_h - 1, context1, context2,
+		      relief);
     RelieveRectangle(theDisplay, man->theWindow, g->button_x+2, g->button_y+2,
-		      g->button_w - 5, g->button_h - 5, context2, context1, 2);
+		      g->button_w - 5, g->button_h - 5, context2, context1,
+		      relief);
   }
   else {
     RelieveRectangle(theDisplay, man->theWindow, g->button_x, g->button_y,
-		      g->button_w - 1, g->button_h - 1, context1, context2, 2);
+		      g->button_w - 1, g->button_h - 1, context1, context2,
+		      relief);
   }
 }
 
@@ -2341,9 +2419,9 @@ void man_exposed(WinManager *man, XEvent *theEvent)
 	}
 }
 
-/***************************************************************************/
-/* Debugging routines                                                      */
-/***************************************************************************/
+/*
+ * Debugging routines
+ */
 
 void check_managers_consistency(void)
 {
