@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This module, and the entire ModuleDebugger program, and the concept for
  * interfacing this module to the Window Manager, are all original work
  * by Robert Nation
@@ -66,11 +67,11 @@ PagerStringList *NewPagerStringItem(PagerStringList *last, int desk);
 extern FlocaleFont *FwindowFont;
 extern Pixmap default_pixmap;
 
-/*************************************************************************
+/*
  *
  * Screen, font, etc info
  *
- **************************************************************************/
+ */
 ScreenInfo Scr;
 PagerWindow *Start = NULL;
 PagerWindow *FocusWin = NULL;
@@ -156,12 +157,12 @@ static void SetDeskLabel(int desk, const char *label);
 static RETSIGTYPE TerminateHandler(int);
 void ExitPager(void);
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      main - start of module
  *
- ***********************************************************************/
+ */
 int main(int argc, char **argv)
 {
   char *display_name = NULL;
@@ -464,12 +465,12 @@ int main(int argc, char **argv)
   return 0;
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      Loop - wait for data to process
  *
- ***********************************************************************/
+ */
 void Loop(int *fd)
 {
   XEvent Event;
@@ -497,12 +498,12 @@ void Loop(int *fd)
 }
 
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      Process message - examines packet types, and takes appropriate action
  *
- ***********************************************************************/
+ */
 void process_message( FvwmPacket* packet )
 {
   unsigned long type = packet->type;
@@ -571,29 +572,31 @@ void process_message( FvwmPacket* packet )
 }
 
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      SIGPIPE handler - SIGPIPE means fvwm is dying
  *
- ***********************************************************************/
+ */
 static RETSIGTYPE
 TerminateHandler(int sig)
 {
   fvwmSetTerminate(sig);
+  SIGNAL_RETURN;
 }
 
-void DeadPipe(int nonsense)
+RETSIGTYPE DeadPipe(int nonsense)
 {
   exit(0);
+  SIGNAL_RETURN;
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      list_add - displays packet contents to stderr
  *
- ***********************************************************************/
+ */
 void list_add(unsigned long *body)
 {
 	PagerWindow *t,**prev;
@@ -653,12 +656,12 @@ void list_add(unsigned long *body)
 	return;
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      list_configure - displays packet contents to stderr
  *
- ***********************************************************************/
+ */
 void list_configure(unsigned long *body)
 {
   PagerWindow *t;
@@ -728,12 +731,12 @@ void list_configure(unsigned long *body)
   }
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      list_destroy - displays packet contents to stderr
  *
- ***********************************************************************/
+ */
 void list_destroy(unsigned long *body)
 {
   PagerWindow *t,**prev;
@@ -769,12 +772,12 @@ void list_destroy(unsigned long *body)
     }
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      list_focus - displays packet contents to stderr
  *
- ***********************************************************************/
+ */
 void list_focus(unsigned long *body)
 {
   PagerWindow *t;
@@ -816,12 +819,12 @@ void list_focus(unsigned long *body)
   }
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      list_new_page - displays packet contents to stderr
  *
- ***********************************************************************/
+ */
 void list_new_page(unsigned long *body)
 {
   Scr.Vx = body[0];
@@ -847,12 +850,12 @@ void list_new_page(unsigned long *body)
   Hilight(FocusWin,True);
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      list_new_desk - displays packet contents to stderr
  *
- ***********************************************************************/
+ */
 void list_new_desk(unsigned long *body)
 {
   int oldDesk;
@@ -1010,12 +1013,12 @@ void list_new_desk(unsigned long *body)
   Hilight(FocusWin,True);
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      list_raise - displays packet contents to stderr
  *
- ***********************************************************************/
+ */
 void list_raise(unsigned long *body)
 {
   PagerWindow *t;
@@ -1036,12 +1039,12 @@ void list_raise(unsigned long *body)
 }
 
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      list_lower - displays packet contents to stderr
  *
- ***********************************************************************/
+ */
 void list_lower(unsigned long *body)
 {
   PagerWindow *t;
@@ -1064,12 +1067,12 @@ void list_lower(unsigned long *body)
 }
 
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      list_iconify - displays packet contents to stderr
  *
- ***********************************************************************/
+ */
 void list_iconify(unsigned long *body)
 {
 	PagerWindow *t;
@@ -1115,12 +1118,12 @@ void list_iconify(unsigned long *body)
 }
 
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      list_deiconify - displays packet contents to stderr
  *
- ***********************************************************************/
+ */
 
 void list_deiconify(unsigned long *body, unsigned long length)
 {
@@ -1218,12 +1221,12 @@ void list_window_name(unsigned long *body,unsigned long type)
     }
 }
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      list_icon_name - displays packet contents to stderr
  *
- ***********************************************************************/
+ */
 void list_icon_name(unsigned long *body)
 {
   PagerWindow *t;
@@ -1331,12 +1334,12 @@ void list_restack(unsigned long *body, unsigned long length)
 }
 
 
-/***********************************************************************
+/*
  *
  *  Procedure:
  *      list_end - displays packet contents to stderr
  *
- ***********************************************************************/
+ */
 void list_end(void)
 {
   unsigned int nchildren,i;
@@ -1425,11 +1428,11 @@ void list_property_change(unsigned long *body)
   }
 }
 
-/***************************************************************************
+/*
  *
  * Waits for next X event, or for an auto-raise timeout.
  *
- ****************************************************************************/
+ */
 int My_XNextEvent(Display *dpy, XEvent *event)
 {
   fd_set in_fdset;
@@ -1578,11 +1581,11 @@ static void SetDeskLabel(int desk, const char *label)
   }
 }
 
-/*****************************************************************************
+/*
  *
  * This routine is responsible for reading and parsing the config file
  *
- ****************************************************************************/
+ */
 void ParseOptions(void)
 {
   char *tline= NULL;
