@@ -1,18 +1,4 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
+/* -*-c-*- */
 #include <libs/Picture.h>
 #include <libs/vpacket.h>
 #include <libs/Flocale.h>
@@ -111,6 +97,7 @@ typedef struct balloon_window
 {
   FlocaleFont *Ffont;
   int height;            /* height of balloon window based on font */
+  int desk;
 } BalloonWindow;
 
 typedef struct desk_info
@@ -143,14 +130,14 @@ typedef struct pager_string_list
   FvwmPicture *bgPixmap;                /* Pixmap used as background. */
 } PagerStringList;
 
-/*************************************************************************
+/*
  *
  * Subroutine Prototypes
  *
- *************************************************************************/
+ */
 char *GetNextToken(char *indata,char **token);
 void Loop(int *fd);
-void DeadPipe(int nonsense) __attribute__((noreturn));
+RETSIGTYPE DeadPipe(int nonsense);
 void process_message(FvwmPacket*);
 void ParseOptions(void);
 
@@ -186,8 +173,9 @@ void nocolor(char *a, char *b);
 void DispatchEvent(XEvent *Event);
 void ReConfigure(void);
 void ReConfigureAll(void);
+void update_pr_transparent_windows(void);
 void MovePage(Bool is_new_desk);
-void DrawGrid(int desk,int erase);
+void DrawGrid(int desk,int erase,Window ew,XRectangle *r);
 void DrawIconGrid(int erase);
 void SwitchToDesk(int Desk);
 void SwitchToDeskAndPage(int Desk, XEvent *Event);
