@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -144,7 +145,7 @@ static void CreateOrUpdateGoodyGC(void)
   }
   else
   {
-	  goodies_width += 0;	  
+	  goodies_width += 0;
   }
 
 }
@@ -219,7 +220,7 @@ Bool GoodiesParseConfig(char *tline)
     if (clockfmt && clockfmt[0] == '\0' && datefmt && datefmt[0] == '\0')
     {
 	    do_display_clock = False;
-    } 
+    }
     break;
   case 4: /* StatusFont */
     CopyStringWithQuotes(&statusfont_string, rest);
@@ -515,6 +516,7 @@ void RedrawTipWindow(void)
     FwinString->str = Tip.text;
     FwinString->x = 3;
     FwinString->y = 2 + FStatusFont->ascent;
+    FwinString->flags.has_clip_region = False;
     if (tipscolorset >= 0)
     {
        FwinString->colorset = &Colorset[tipscolorset];
@@ -526,7 +528,7 @@ void RedrawTipWindow(void)
     }
     if (FftSupport && FStatusFont->fftf.fftfont != NULL)
     {
-       XClearArea(dpy, Tip.win, 0, 0, Tip.w, Tip.h, False);
+	    XClearArea(dpy, Tip.win, 0, 0, Tip.w, Tip.h, False);
     }
     FlocaleDrawString(dpy, FStatusFont, FwinString, 0);
     XRaiseWindow(dpy, Tip.win);
@@ -577,6 +579,7 @@ void ShowTipWindow(int open)
     if (Tip.win != None)
     {
       XMapRaised(dpy, Tip.win);
+      RedrawTipWindow();
     }
   }
   else
