@@ -42,6 +42,8 @@ int StartAndLaunchButtonsHeight = 0;
 int WindowButtonsLeftMargin = 4;    /* default value is 4 */
 int WindowButtonsRightMargin = 2;   /* default value is 2 */
 int StartButtonRightMargin = 0;     /* default value is 0 */
+int has_wb_left_margin = 0;
+int has_wb_right_margin = 0;
 Bool StartButtonOpensAboveTaskBar = FALSE;
 char *StartName     = NULL,
      *StartCommand  = NULL,
@@ -226,13 +228,17 @@ Bool StartButtonParseConfig(char *tline)
 		titleRecorded = iconRecorded = 0;
 		tokens[j++] = strtok_r(rest, ",", &strtok_ptr);
 		while((tokens[j++] = strtok_r(NULL, ",", &strtok_ptr)))
-			while(*(tokens[j-1])==' ')
+		{
+			while(isspace(*(tokens[j-1])))
+			{
 				tokens[j-1]+=sizeof(char);
+			}
+		}
 		j--;
 
 		for(k=0;k<j;k++)
 		{
-			if (strncmp(tokens[k], "Title", 5)==0)
+			if (strncasecmp(tokens[k], "Title", 5)==0)
 			{
 				tokens[j+1] = tokens[k] + ((sizeof(char))*5);
 				while(*(tokens[j+1])==' ')
@@ -242,7 +248,7 @@ Bool StartButtonParseConfig(char *tline)
 					tokens[j+1]);
 				titleRecorded=1;
 			}
-			else if (strncmp(tokens[k], "Icon", 4)==0)
+			else if (strncasecmp(tokens[k], "Icon", 4)==0)
 			{
 				tokens[j+1] = tokens[k] + ((sizeof(char))*4);
 				while(*(tokens[j+1])==' ')
@@ -252,7 +258,7 @@ Bool StartButtonParseConfig(char *tline)
 					tokens[j+1] );
 				iconRecorded = 1;
 			}
-			else if (strncmp(tokens[k], "Action", 6)==0)
+			else if (strncasecmp(tokens[k], "Action", 6)==0)
 			{
 				rest = tokens[k] + ((sizeof(char))*6);
 				rest = ParseButtonOptions(rest, &mouseButton);
@@ -294,12 +300,14 @@ Bool StartButtonParseConfig(char *tline)
 		if(atoi(rest)>=0)
 		{
 			WindowButtonsLeftMargin = atoi(rest);
+			has_wb_left_margin = 1;
 		}
 		break;
 	case 7: /* WindowButtonsRightMargin */
 		if(atoi(rest)>=0)
 		{
 			WindowButtonsRightMargin = atoi(rest);
+			has_wb_right_margin = 1;
 		}
 		break;
 	case 8: /* StartButtonRightMargin */
@@ -311,7 +319,6 @@ Bool StartButtonParseConfig(char *tline)
 	default:
 		/* unknown option */
 		return False;
-		break;
 	} /* switch */
 
 	return True;
@@ -455,10 +462,16 @@ void StartButtonInit(int height)
   }
   else
   {
-	  StartAndLaunchButtonsWidth = 0;
-	  StartButtonRightMargin = 0;
-	  WindowButtonsLeftMargin = 0;
-	  WindowButtonsRightMargin = 0;
+    StartAndLaunchButtonsWidth = 0;
+    StartButtonRightMargin = 0;
+    if (has_wb_left_margin == 0)
+    {
+      WindowButtonsLeftMargin = 0;
+    }
+    if (has_wb_right_margin == 0)
+    {
+      WindowButtonsRightMargin = 0;
+    }
   }
 }
 
