@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -5,33 +6,34 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 /*
  * Generic graphics and misc. utilities
- *
  */
 
+#include "config.h"
+
 #include <X11/Xlib.h>
 #include <stdlib.h>
 extern Window main_win;
 #include "libs/fvwmlib.h"
 #include "libs/PictureBase.h"
+#include "libs/PictureUtils.h"
 
 /* Masks to apply to color components when allocating colors
  * you may want to set them to 0xffff if your display supports 16bpp+
  */
-#define RED_MASK	0xff00
-#define GREEN_MASK	0xff00
-#define BLUE_MASK	0xff00
+#define RED_MASK        0xff00
+#define GREEN_MASK      0xff00
+#define BLUE_MASK       0xff00
 /*
- ***********************************************************************
  * Allocates colors and fill a pixel value array. Color values are
  * truncated with RED_MASK, GREEN_MASK and BLUE_MASK
  *
@@ -42,7 +44,6 @@ extern Window main_win;
  * dr,dg,db are the increment values for the colors
  * alloc_relief if colors for relief should be allocated
  * incr - 0 if gradient is light to dark, 1 if dark to light
- ***********************************************************************
  */
 int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols,
 	       unsigned long *colors, unsigned long *dark,
@@ -74,8 +75,7 @@ int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols,
 	    color.red = red;
 	    color.green = green;
 	    color.blue = blue;
-	    if (XAllocColor(dpy, DefaultColormap(dpy, DefaultScreen(dpy)),
-			&color)==0) {
+	    if (PictureAllocColor(dpy, Pcmap, &color, True)==0) {
 		return 0;
 	    }
 	}
@@ -101,7 +101,7 @@ int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols,
 	color.red = (unsigned short)(rv<0?0:rv);
     color.green = (unsigned short)(gv<0?0:gv);
 	color.blue = (unsigned short)(bv<0?0:bv);
-	if (XAllocColor(dpy, DefaultColormap(dpy, DefaultScreen(dpy)),&color))
+	if (PictureAllocColor(dpy, Pcmap, &color, True))
 	  *dark = color.pixel;
 	else
 	  *dark = colors[incr ? 0 : maxcols-1];
@@ -122,8 +122,7 @@ int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols,
 	color.red = (unsigned short)(rv>65535.0 ? 65535.0:rv);
     color.green = (unsigned short)(gv>65535.0 ? 65535.0:gv);
 	color.blue = (unsigned short)(bv>65535.0 ? 65535.0:bv);
-	if (XAllocColor(dpy, DefaultColormap(dpy, DefaultScreen(dpy)),
-			&color))
+	if (PictureAllocColor(dpy, Pcmap, &color, True))
 	  *light = color.pixel;
 	else
 	  *light = colors[incr ? maxcols-1 : 0];
@@ -136,7 +135,6 @@ int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols,
 
 
 /*
- ************************************************************************
  *
  * Draws a texture similar to Wharf's button background
  *
@@ -146,22 +144,21 @@ int MakeColors(Display *dpy, Drawable d, int from[3], int to[3], int maxcols,
  * maxcols: # of max colors to use
  *
  * Aborts and returns 0 on error
- ************************************************************************
  */
 
 int DrawDegradeRelief(Display *dpy, Drawable d, int x, int y, int w, int h,
 		       int from[3], int to[3], int relief, int maxcols)
 {
-    int		i = 0,j,k;
-    int		dr, dg, db;  /* delta */
-    int		dmax, dmax2;
-    GC		gc, gc2;
-    XGCValues	gcv;
-    int		px, py, pd;
+    int         i = 0,j,k;
+    int         dr, dg, db;  /* delta */
+    int         dmax, dmax2;
+    GC          gc, gc2;
+    XGCValues   gcv;
+    int         px, py, pd;
     unsigned long lightcolor, darkcolor;
-    int		alloc_relief;
+    int         alloc_relief;
     unsigned long  *colors;
-    float	c1,s1;
+    float       c1,s1;
 
     if (w <= 0 || h <= 0)
       return 0;
@@ -250,8 +247,6 @@ int DrawDegradeRelief(Display *dpy, Drawable d, int x, int y, int w, int h,
 
 
 /*
- ************************************************************************
- *
  * Draws a horizontal gradient
  *
  * from: r,g,b values of top color
@@ -261,21 +256,20 @@ int DrawDegradeRelief(Display *dpy, Drawable d, int x, int y, int w, int h,
  * type: gradient type. 0 for one-way, != 0 for cilindrical
  *
  * aborts and returns 0 on error.
- ************************************************************************
  */
 int DrawHGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 		       int from[3], int to[3], int relief, int maxcols,
 		       int type)
 {
-    int		i,j;
-    XGCValues	gcv;
-    GC		gc, gc2;
-    int		dr,dg,db;
-    float	s,c;
-    int		dmax;
+    int         i,j;
+    XGCValues   gcv;
+    GC          gc, gc2;
+    int         dr,dg,db;
+    float       s,c;
+    int         dmax;
     unsigned long  *colors, lightcolor, darkcolor;
-    int		py,pd;
-    int		alloc_relief;
+    int         py,pd;
+    int         alloc_relief;
 
     if (w <= 1 || h <= 1)
       return 0;
@@ -374,8 +368,6 @@ int DrawHGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 
 
 /*
- ************************************************************************
- *
  * Draws a vertical gradient
  *
  * from: r,g,b values of left color
@@ -385,21 +377,20 @@ int DrawHGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
  * type: gradient type. 0 for one-way, != 0 for cilindrical
  *
  * aborts and returns 0 on error.
- ************************************************************************
  */
 int DrawVGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 		       int from[3], int to[3], int relief, int maxcols,
 		       int type)
 {
-    int		i,j;
-    XGCValues	gcv;
-    GC		gc, gc2;
-    int		dr,dg,db;
-    float	s,c;
-    int		dmax;
+    int         i,j;
+    XGCValues   gcv;
+    GC          gc, gc2;
+    int         dr,dg,db;
+    float       s,c;
+    int         dmax;
     unsigned long  *colors, lightcolor, darkcolor;
-    int		px,pd;
-    int		alloc_relief;
+    int         px,pd;
+    int         alloc_relief;
 
     if (w <= 1 || h <= 1)
       return 0;
@@ -497,9 +488,7 @@ int DrawVGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
 }
 
 
-/************************************************************************
- *
- * Draws text with a texture
+/* Draws text with a texture
  *
  * d - target drawable
  * font - font to draw text
@@ -507,7 +496,7 @@ int DrawVGradient(Display *dpy, Drawable d, int x, int y, int w, int h,
  * gradient - texture pixmap. size must be at least as large as text
  * text - text to draw
  * chars - chars in text
- ************************************************************************/
+ */
 void DrawTexturedText(Display *dpy, Drawable d, XFontStruct *font,
 		      int x, int y, Pixmap gradient, char *text, int chars)
 
@@ -574,7 +563,7 @@ int MakeShadowColors(Display *dpy, int from[3], int to[3],
 	color.red = (short)(rv<0?0:rv);
 	color.green = (short)(gv<0?0:gv);
 	color.blue = (short)(bv<0?0:bv);
-	if (XAllocColor(dpy, Pcmap ,&color))
+	if (PictureAllocColor(dpy, Pcmap ,&color, True))
 	  *dark = color.pixel;
 	else
 	  return 0;
@@ -595,7 +584,7 @@ int MakeShadowColors(Display *dpy, int from[3], int to[3],
 	color.red = (unsigned short)(rv>65535.0 ? 65535.0:rv);
 	color.green = (unsigned short)(gv>65535.0 ? 65535.0:gv);
 	color.blue = (unsigned short)(bv>65535.0 ? 65535.0:bv);
-	if (XAllocColor(dpy, Pcmap, &color))
+	if (PictureAllocColor(dpy, Pcmap, &color, True))
 	  *light = color.pixel;
 	else
 	  return 0;
