@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* FvwmWinList Module for Fvwm.
  *
  *  Copyright 1994,  Mike Finger (mfinger@mermaid.micro.umn.edu or
@@ -67,6 +68,7 @@
 #include "libs/gravity.h"
 #include "libs/FRender.h"
 #include "libs/FRenderInterface.h"
+#include "libs/fvwmrect.h"
 
 #include "FvwmWinList.h"
 #include "ButtonArray.h"
@@ -162,13 +164,15 @@ struct
 	unsigned needs_resize_after_unshade : 1;
 } flags = { 0, 0 };
 
+rectangle cfg_g = { 0, 0, 0, 0 }; /* win geometry from M_CONFIGURE_WINDOW */
+
 static RETSIGTYPE TerminateHandler(int sig);
 
 static char *AnimCommand = NULL;
 
-/***************************************************************************
+/*
  * TerminateHandler - reentrant signal handler that ends the main event loop
- ***************************************************************************/
+ */
 static RETSIGTYPE TerminateHandler(int sig)
 {
   /*
@@ -177,6 +181,7 @@ static RETSIGTYPE TerminateHandler(int sig)
    * BEFORE we call it ...
    */
   fvwmSetTerminate(sig);
+  SIGNAL_RETURN;
 }
 
 static void window_shade(unsigned long *body, int do_shade)
@@ -206,11 +211,11 @@ static void window_shade(unsigned long *body, int do_shade)
 	return;
 }
 
-/******************************************************************************
+/*
   Main - Setup the XConnection,request the window list and loop forever
     Based on main() from FvwmIdent:
       Copyright 1994, Robert Nation and Nobutaka Suzuki.
-******************************************************************************/
+*/
 int main(int argc, char **argv)
 {
   char *temp, *s;
@@ -349,9 +354,9 @@ int main(int argc, char **argv)
 }
 
 
-/******************************************************************************
+/*
   MainEventLoop -  Read and redraw until we die, blocking when can't read
-******************************************************************************/
+*/
 void MainEventLoop(void)
 {
   fd_set readset;
@@ -376,11 +381,11 @@ void MainEventLoop(void)
   } /* while */
 }
 
-/******************************************************************************
+/*
   ReadFvwmPipe - Read a single message from the pipe from Fvwm
     Originally Loop() from FvwmIdent:
       Copyright 1994, Robert Nation and Nobutaka Suzuki.
-******************************************************************************/
+*/
 void ReadFvwmPipe(void)
 {
     FvwmPacket* packet = ReadFvwmPacket(Fvwm_fd[1]);
@@ -390,11 +395,11 @@ void ReadFvwmPipe(void)
 	ProcessMessage( packet->type, packet->body );
 }
 
-/******************************************************************************
+/*
   ProcessMessage - Process the message coming from Fvwm
     Skeleton based on processmessage() from FvwmIdent:
       Copyright 1994, Robert Nation and Nobutaka Suzuki.
-******************************************************************************/
+*/
 void ProcessMessage(unsigned long type,unsigned long *body)
 {
   int redraw=0,i,j;
@@ -411,9 +416,13 @@ void ProcessMessage(unsigned long type,unsigned long *body)
       cfgpacket = (void *) body;
       /* We get the win_borders only when WinList  map it self, this is ok
        *  since we need it only after an unmap */
-#ifdef COMPLEX_WINDOW_PLACEMENT
       if (cfgpacket->w == win)
       {
+	cfg_g.x = cfgpacket->frame_x;
+	cfg_g.y = cfgpacket->frame_y;
+	cfg_g.width = cfgpacket->frame_width;
+	cfg_g.height = cfgpacket->frame_height;
+#ifdef COMPLEX_WINDOW_PLACEMENT
 	win_border_x = win_border_y = cfgpacket->border_width;
 	if (((win_grav == NorthWestGravity || win_grav == NorthEastGravity)
 	     && HAS_TITLE_DIR(cfgpacket, DIR_N)) ||
@@ -429,8 +438,8 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 	{
 	  win_border_x +=  cfgpacket->title_height;
 	}
-      }
 #endif
+      }
       if ((i = FindItem(&windows,cfgpacket->w))!=-1)
       {
 	flagitem=ItemFlags(&windows,cfgpacket->w);
@@ -507,30 +516,55 @@ void ProcessMessage(unsigned long type,unsigned long *body)
     case M_ICONIFY:
       /* fwvm will wait for an Unlock message before continuing
        * be careful when changing this construct, make sure unlock happens */
-      if ((i = FindItem(&windows, body[0])) != -1) {
+      if ((i = FindItem(&windows, body[0])) != -1)
+      {
 	flagitem = ItemFlags(&windows, body[0]);
 	if ((type == M_DEICONIFY && IS_ICONIFIED(flagitem))
-	    || (type == M_ICONIFY && !IS_ICONIFIED(flagitem))) {
+	    || (type == M_ICONIFY && !IS_ICONIFIED(flagitem)))
+	{
 	  if (IS_ICON_SUPPRESSED(flagitem) && IsItemIndexVisible(&windows,i)
-	      && AnimCommand && WindowState && AnimCommand[0] != 0) {
+	      && AnimCommand && WindowState && AnimCommand[0] != 0)
+	  {
 	    char buff[MAX_MODULE_INPUT_TEXT_LEN];
 	    Window child;
-	    int x, y;
+	    int x, y, w, h;
 
 	    /* find out where our button is */
 	    j = FindItemVisible(&windows, body[0]);
-	    XTranslateCoordinates(dpy, win, Root, 0, j * buttonheight,
-				  &x, &y, &child);
+	    XTranslateCoordinates(
+		    dpy, win, Root, 0, j * buttonheight, &x, &y, &child);
+	    w = win_width;
+	    h = buttonheight;
+	    if (flags.is_shaded)
+	    {
+		    if (w > cfg_g.width - win_border_x)
+		    {
+			    w = 1;
+		    }
+		    if (h > cfg_g.height - win_border_y)
+		    {
+			    h = 1;
+		    }
+		    if (x < cfg_g.x || x > cfg_g.x + cfg_g.width)
+		    {
+			    x = cfg_g.x + win_border_x;
+		    }
+		    if (y < cfg_g.y || y > cfg_g.y + cfg_g.height)
+		    {
+			    y = cfg_g.y + win_border_y;
+		    }
+
+	    }
 	    /* tell FvwmAnimate to animate to our button */
 	    if (IS_ICONIFIED(flagitem)) {
-	      sprintf(buff, "%s %d %d %d %d %d %d %d %d", AnimCommand,
-		      x, y, win_width, buttonheight,
-		      (int)body[7], (int)body[8], (int)body[9],
-		      (int)body[10]);
+		    sprintf(buff, "%s %d %d %d %d %d %d %d %d", AnimCommand,
+			    x, y, w, h, (int)body[7], (int)body[8],
+			    (int)body[9], (int)body[10]);
 	    } else {
-	      sprintf(buff, "%s %d %d %d %d %d %d %d %d", AnimCommand,
-		      (int)body[7], (int)body[8], (int)body[9], (int)body[10],
-		      x, y, win_width, buttonheight);
+		    sprintf(buff, "%s %d %d %d %d %d %d %d %d", 
+			    AnimCommand, (int)body[7], (int)body[8],
+			    (int)body[9], (int)body[10],
+			    x, y, w, h);
 	    }
 	    SendText(Fvwm_fd, buff, 0);
 	  }
@@ -596,9 +630,9 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 }
 
 
-/******************************************************************************
+/*
   RedrawWindow - Update the needed lines and erase any old ones
-******************************************************************************/
+*/
 void RedrawWindow(Bool force, Bool clear_bg, XEvent *evp)
 {
   DrawButtonArray(&buttons, force, clear_bg, evp);
@@ -606,9 +640,9 @@ void RedrawWindow(Bool force, Bool clear_bg, XEvent *evp)
   if (FQLength(dpy) && !force) LoopOnEvents();
 }
 
-/******************************************************************************
+/*
   ConsoleMessage - Print a message on the console.  Works like printf.
-******************************************************************************/
+*/
 void ConsoleMessage(const char *fmt, ...)
 {
 #ifndef NO_CONSOLE
@@ -623,9 +657,9 @@ void ConsoleMessage(const char *fmt, ...)
 #endif
 }
 
-/******************************************************************************
+/*
   OpenConsole - Open the console as a way of sending messages
-******************************************************************************/
+*/
 int OpenConsole(void)
 {
 #ifndef NO_CONSOLE
@@ -637,11 +671,11 @@ int OpenConsole(void)
   return 1;
 }
 
-/******************************************************************************
+/*
   ParseConfig - Parse the configuration file fvwm to us to use
     Based on part of main() from FvwmIdent:
       Copyright 1994, Robert Nation and Nobutaka Suzuki.
-******************************************************************************/
+*/
 void ParseConfig(void)
 {
   char *tline;
@@ -810,9 +844,9 @@ ParseConfigLine(char *tline)
 }
 
 
-/******************************************************************************
+/*
   LoopOnEvents - Process all the X events we get
-******************************************************************************/
+*/
 void LoopOnEvents(void)
 {
   int num;
@@ -977,9 +1011,9 @@ void LoopOnEvents(void)
 }
 
 
-/******************************************************************************
+/*
   AdjustWindow - Resize the window according to maxwidth by number of buttons
-******************************************************************************/
+*/
 void AdjustWindow(Bool force)
 {
   int new_width=0,new_height=0,tw,i,total,all;
@@ -1135,9 +1169,9 @@ void AdjustWindow(Bool force)
   }
 }
 
-/******************************************************************************
+/*
   makename - Based on the flags return me '(name)' or 'name'
-******************************************************************************/
+*/
 char *makename(const char *string, Bool iconified)
 {
   char *ptr;
@@ -1149,9 +1183,9 @@ char *makename(const char *string, Bool iconified)
   return ptr;
 }
 
-/******************************************************************************
+/*
   LinkAction - Link an response to a users action
-******************************************************************************/
+*/
 void LinkAction(char *string)
 {
 char *temp;
@@ -1174,9 +1208,9 @@ char *temp;
     CopyString(&EnterAction,&temp[5]);
 }
 
-/******************************************************************************
+/*
   MakeMeWindow - Create and setup the window we will need
-******************************************************************************/
+*/
 void MakeMeWindow(void)
 {
   XSizeHints hints;
@@ -1459,9 +1493,9 @@ void MakeMeWindow(void)
   }
 }
 
-/******************************************************************************
+/*
   StartMeUp - Do X initialization things
-******************************************************************************/
+*/
 void StartMeUp_I(void)
 {
   if (!(dpy = XOpenDisplay("")))
@@ -1510,9 +1544,9 @@ void StartMeUp_II(void)
 
 }
 
-/******************************************************************************
+/*
   ShutMeDown - Do X client cleanup
-******************************************************************************/
+*/
 void ShutMeDown(void)
 {
   FreeList(&windows);
@@ -1522,11 +1556,11 @@ void ShutMeDown(void)
   XCloseDisplay(dpy);
 }
 
-/******************************************************************************
+/*
   ChangeWindowName - Self explanitory
     Original work from FvwmIdent:
       Copyright 1994, Robert Nation and Nobutaka Suzuki.
-******************************************************************************/
+*/
 void ChangeWindowName(char *str)
 {
   XTextProperty name;
@@ -1539,11 +1573,11 @@ void ChangeWindowName(char *str)
   XFree(name.value);
 }
 
-/**************************************************************************
+/*
  *
  * Sets mwm hints
  *
- *************************************************************************/
+ */
 /*
  *  Now, if we (hopefully) have MWW - compatible window manager ,
  *  say, mwm, ncdwm, or else, we will set useful decoration style.
@@ -1576,9 +1610,9 @@ PropMwmHints prop;
     }
 }
 
-/************************************************************************
+/*
   X Error Handler
-************************************************************************/
+*/
 int ErrorHandler(Display *d, XErrorEvent *event)
 {
   /* some errors are OK=ish */
@@ -1586,7 +1620,7 @@ int ErrorHandler(Display *d, XErrorEvent *event)
     return 0;
   if (event->error_code == BadDrawable)
     return 0;
-if (FRenderGetErrorCodeBase() + FRenderBadPicture == event->error_code)
+  if (FRenderGetErrorCodeBase() + FRenderBadPicture == event->error_code)
     return 0;
 
   PrintXErrorAndCoredump(d, event, Module);
