@@ -1,3 +1,6 @@
+/* -*-c-*- */
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 
